# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.beneficiary_identity_list_item

class BeneficiaryIdentityListItems(object):

    """Implementation of the 'BeneficiaryIdentityListItems' model.

    The beneficiaryIdentityField contains optional listItem sub-elements. The
    listItem sub-elements would normally be present where the inputType
    attribute is 'list'.

    Attributes:
        beneficiary_identity_field (list of BeneficiaryIdentityListItem):
            TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "beneficiary_identity_field":'beneficiaryIdentityField'
    }

    def __init__(self,
                 beneficiary_identity_field=None):
        """Constructor for the BeneficiaryIdentityListItems class"""

        # Initialize members of the class
        self.beneficiary_identity_field = beneficiary_identity_field


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        beneficiary_identity_field = None
        if dictionary.get('beneficiaryIdentityField') != None:
            beneficiary_identity_field = list()
            for structure in dictionary.get('beneficiaryIdentityField'):
                beneficiary_identity_field.append(earthport-rest-api-client.models.beneficiary_identity_list_item.BeneficiaryIdentityListItem.from_dictionary(structure))

        # Return an object of this model
        return cls(beneficiary_identity_field)





# -*- coding: utf-8 -*-

class AdditionalInformationEnum(object):

    """Implementation of the 'AdditionalInformation' enum.

    TODO: type enum description here.

    Attributes:
        UNIQUETRANSACTIONID: TODO: type description here.
        INSTRUCTEDCURRENCY: TODO: type description here.
        INSTRUCTEDAMOUNT: TODO: type description here.
        SETTLEDCURRENCY: TODO: type description here.
        SETTLEDAMOUNT: TODO: type description here.
        SETTLEDDATE: TODO: type description here.
        DEBITCREDITINDICATOR: TODO: type description here.
        TRANSACTIONTYPE: TODO: type description here.
        TRANSACTIONNARRATIVE: TODO: type description here.
        ADDITIONALNARRATIVE: TODO: type description here.
        ORIGINATORBANK: TODO: type description here.
        ORIGINATORACCOUNTNUMBER: TODO: type description here.
        ORIGINATORNAMEADDRESSCOMBINED: TODO: type description here.
        ORIGINATORACCOUNTNAME: TODO: type description here.
        ORIGINATORADDRESS: TODO: type description here.
        ORIGINATORCITY: TODO: type description here.
        ORIGINATORCOUNTRY: TODO: type description here.
        ORIGINATORDOB: TODO: type description here.
        ORIGINATORNATIONALID: TODO: type description here.
        BENEFICIARYNAMEADDRESSCOMBINED: TODO: type description here.
        BENEFICIARYNAME: TODO: type description here.
        BENEFICIARYDOB: TODO: type description here.
        BENEFICIARYNATIONALID: TODO: type description here.
        BENEFICIARYADDRESS: TODO: type description here.
        BENEFICIARYCITY: TODO: type description here.
        BENEFICIARYCOUNTRY: TODO: type description here.

    """

    UNIQUETRANSACTIONID = 'UniqueTransactionId'

    INSTRUCTEDCURRENCY = 'InstructedCurrency'

    INSTRUCTEDAMOUNT = 'InstructedAmount'

    SETTLEDCURRENCY = 'SettledCurrency'

    SETTLEDAMOUNT = 'SettledAmount'

    SETTLEDDATE = 'SettledDate'

    DEBITCREDITINDICATOR = 'DebitCreditIndicator'

    TRANSACTIONTYPE = 'TransactionType'

    TRANSACTIONNARRATIVE = 'TransactionNarrative'

    ADDITIONALNARRATIVE = 'AdditionalNarrative'

    ORIGINATORBANK = 'OriginatorBank'

    ORIGINATORACCOUNTNUMBER = 'OriginatorAccountNumber'

    ORIGINATORNAMEADDRESSCOMBINED = 'OriginatorNameAddressCombined'

    ORIGINATORACCOUNTNAME = 'OriginatorAccountName'

    ORIGINATORADDRESS = 'OriginatorAddress'

    ORIGINATORCITY = 'OriginatorCity'

    ORIGINATORCOUNTRY = 'OriginatorCountry'

    ORIGINATORDOB = 'OriginatorDOB'

    ORIGINATORNATIONALID = 'OriginatorNationalId'

    BENEFICIARYNAMEADDRESSCOMBINED = 'BeneficiaryNameAddressCombined'

    BENEFICIARYNAME = 'BeneficiaryName'

    BENEFICIARYDOB = 'BeneficiaryDOB'

    BENEFICIARYNATIONALID = 'BeneficiaryNationalId'

    BENEFICIARYADDRESS = 'BeneficiaryAddress'

    BENEFICIARYCITY = 'BeneficiaryCity'

    BENEFICIARYCOUNTRY = 'BeneficiaryCountry'




# -*- coding: utf-8 -*-


class BenBankID(object):

    """Implementation of the 'BenBankID' model.

    This group consists of all possible beneficiary bank identifier types. The
    'epBankID' field is a unique identifier for a beneficiary bank account.
    The 'merchantBankID' is an optional merchant specified identifier for the
    beneficiary bank account. The 'epBankID', 'merchantBankID' or both
    'epBankID' and 'merchantBankID' can be supplied. A mapping will be
    performed to retrieve the merchant bank ID from the supplied EP bank ID
    and vice versa. If both the 'epBankID' and 'merchantBankID' are supplied,
    a check will be performed to ensure that the two are mapped. If the two
    provided fields are not mapped, then a validation error code will be
    returned. At least one of the fields must be populated.

    Attributes:
        ep_bank_id (int): The unique ID of a beneficiary bank account.
        merchant_bank_id (string): The merchant specified ID for a beneficiary
            bank account.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "ep_bank_id":'epBankID',
        "merchant_bank_id":'merchantBankID'
    }

    def __init__(self,
                 ep_bank_id=None,
                 merchant_bank_id=None):
        """Constructor for the BenBankID class"""

        # Initialize members of the class
        self.ep_bank_id = ep_bank_id
        self.merchant_bank_id = merchant_bank_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        ep_bank_id = dictionary.get('epBankID')
        merchant_bank_id = dictionary.get('merchantBankID')

        # Return an object of this model
        return cls(ep_bank_id,
                   merchant_bank_id)





# -*- coding: utf-8 -*-

class BeneficiaryIdentityFieldInputEnum(object):

    """Implementation of the 'BeneficiaryIdentityFieldInput' enum.

    Supported input types for a beneficiary identity UI.

    Attributes:
        TEXT: TODO: type description here.
        DATE: TODO: type description here.
        NUMBER: TODO: type description here.
        LIST: TODO: type description here.

    """

    TEXT = 'text'

    DATE = 'date'

    NUMBER = 'number'

    LIST = 'list'




# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.monetary_value
import earthport-rest-api-client.models.fx_rate

class FXDetail(object):

    """Implementation of the 'FXDetail' model.

    Represents the details of an FX transaction, encapsulating the sellAmount,
    buyAmount and fxRate into a single type.

    Attributes:
        buy_amount (MonetaryValue): Represents a monetary value containing a
            decimal amount value along with a currency code. The currency code
            is a three letter ISO 4217 code. E.g. GBP for British sterling
            pounds.
        fx_rate (FXRate): Represents an FX rate between two currencies, the
            rate is restricted to 6 decimal places. The currency code is a
            three letter ISO 4217 code. E.g. GBP for British sterling pounds.
        sell_amount (MonetaryValue): Represents a monetary value containing a
            decimal amount value along with a currency code. The currency code
            is a three letter ISO 4217 code. E.g. GBP for British sterling
            pounds.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "buy_amount":'buyAmount',
        "fx_rate":'fxRate',
        "sell_amount":'sellAmount'
    }

    def __init__(self,
                 buy_amount=None,
                 fx_rate=None,
                 sell_amount=None):
        """Constructor for the FXDetail class"""

        # Initialize members of the class
        self.buy_amount = buy_amount
        self.fx_rate = fx_rate
        self.sell_amount = sell_amount


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        buy_amount = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('buyAmount')) if dictionary.get('buyAmount') else None
        fx_rate = earthport-rest-api-client.models.fx_rate.FXRate.from_dictionary(dictionary.get('fxRate')) if dictionary.get('fxRate') else None
        sell_amount = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('sellAmount')) if dictionary.get('sellAmount') else None

        # Return an object of this model
        return cls(buy_amount,
                   fx_rate,
                   sell_amount)





# -*- coding: utf-8 -*-

class TransactionTypeEnum(object):

    """Implementation of the 'transactionType' enum.

    TODO: type enum description here.

    Attributes:
        PAYOUT: TODO: type description here.
        REFUND: TODO: type description here.
        ENUM_USER DEPOSIT: TODO: type description here.
        ENUM_MERCHANT LIQUIDITY DEPOSIT: TODO: type description here.
        ENUM_EARTHPORT TO MERCHANT LIQUIDITY TRANSFER: TODO: type description
            here.
        ENUM_MERCHANT LIQUIDITY MOVEMENT: TODO: type description here.
        JOURNAL: TODO: type description here.
        ENUM_GENERIC TRANSACTION: TODO: type description here.

    """

    PAYOUT = 'Payout'

    REFUND = 'Refund'

    ENUM_USER_DEPOSIT = 'User Deposit'

    ENUM_MERCHANT_LIQUIDITY_DEPOSIT = 'Merchant Liquidity Deposit'

    ENUM_EARTHPORT_TO_MERCHANT_LIQUIDITY_TRANSFER = 'Earthport to Merchant Liquidity Transfer'

    ENUM_MERCHANT_LIQUIDITY_MOVEMENT = 'Merchant Liquidity Movement'

    JOURNAL = 'Journal'

    ENUM_GENERIC_TRANSACTION = 'Generic Transaction'




# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.financial_transaction

class StatementLineItem(object):

    """Implementation of the 'StatementLineItem' model.

    A statement line item is a financial transaction that affects the balance
    of an account.

    Attributes:
        transaction (FinancialTransaction): Minimum set of data that
            constitutes a financial transaction.
        balance (float): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "transaction":'transaction',
        "balance":'balance'
    }

    def __init__(self,
                 transaction=None,
                 balance=None):
        """Constructor for the StatementLineItem class"""

        # Initialize members of the class
        self.transaction = transaction
        self.balance = balance


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        transaction = earthport-rest-api-client.models.financial_transaction.FinancialTransaction.from_dictionary(dictionary.get('transaction')) if dictionary.get('transaction') else None
        balance = dictionary.get('balance')

        # Return an object of this model
        return cls(transaction,
                   balance)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.monetary_value

class AccountBalance(object):

    """Implementation of the 'AccountBalance' model.

    This element represents the balance of a merchant account or a managed
    merchant account.

    Attributes:
        balance (MonetaryValue): Represents a monetary value containing a
            decimal amount value along with a currency code. The currency code
            is a three letter ISO 4217 code. E.g. GBP for British sterling
            pounds.
        balance_timestamp (string): TODO: type description here.
        last_movement_timestamp (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "balance":'balance',
        "balance_timestamp":'balanceTimestamp',
        "last_movement_timestamp":'lastMovementTimestamp'
    }

    def __init__(self,
                 balance=None,
                 balance_timestamp=None,
                 last_movement_timestamp=None):
        """Constructor for the AccountBalance class"""

        # Initialize members of the class
        self.balance = balance
        self.balance_timestamp = balance_timestamp
        self.last_movement_timestamp = last_movement_timestamp


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        balance = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('balance')) if dictionary.get('balance') else None
        balance_timestamp = dictionary.get('balanceTimestamp')
        last_movement_timestamp = dictionary.get('lastMovementTimestamp')

        # Return an object of this model
        return cls(balance,
                   balance_timestamp,
                   last_movement_timestamp)





# -*- coding: utf-8 -*-

class ServiceLevelEnum(object):

    """Implementation of the 'ServiceLevel' enum.

    Supported service levels for a payout request (standard or express).

    Attributes:
        STANDARD: TODO: type description here.
        EXPRESS: TODO: type description here.

    """

    STANDARD = 'standard'

    EXPRESS = 'express'




# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.transaction_id_merchant
import earthport-rest-api-client.models.monetary_value
import earthport-rest-api-client.models.beneficiary_amount_information
import earthport-rest-api-client.models.payout_details
import earthport-rest-api-client.models.transaction_hold

class PaymentRegisteredBeneficiaryRequest(object):

    """Implementation of the 'PaymentRegisteredBeneficiaryRequest' model.

    Beneficiary Bank account payment

    Attributes:
        transaction_id (TransactionIDMerchant): This group consists of
            merchant transaction reference only.
        payout_request_amount (MonetaryValue): Represents a monetary value
            containing a decimal amount value along with a currency code. The
            currency code is a three letter ISO 4217 code. E.g. GBP for
            British sterling pounds.
        beneficiary_amount_information (BeneficiaryAmountInformation): Used to
            specify the beneficiary amount and the payout currency.
        service_level (ServiceLevelEnum): Supported service levels for a
            payout request (standard or express).
        beneficiary_statement_narrative (string): Generic description field.
        fx_ticket_id (int): Generic entity identity.
        requested_fx (RequestedFXEnum): Method of FX that is requested by the
            merchant and for which EPS2 will attempt to use in order to settle
            the payout request. FF (Fixed to Fixed) is where no FX will be
            performed as payout and beneficiary currencies are the same. FV
            (Fixed to Variable) uses the supplied payout request amount in
            order to determine the beneficiary amount. VF (Variable to Fixed)
            uses the supplied beneficiary amount in order to determine the
            payout amount.
        payer_type (PayerTypeEnum): The type of Payer making the payment. This
            detrmines which identity details are used as the payer identity.
        payout_type (string): Reserved for future use. Will be used to state
            the Payout type.
        payout_details (list of PayoutDetails): TODO: type description here.
        transaction_hold (TransactionHold): Parameter to prevent transactions
            from being processed until the desired time has been reached Note
            releaseDateTime must be in UTC format.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "transaction_id":'transactionID',
        "payout_details":'payoutDetails',
        "payout_request_amount":'payoutRequestAmount',
        "beneficiary_amount_information":'beneficiaryAmountInformation',
        "service_level":'serviceLevel',
        "beneficiary_statement_narrative":'beneficiaryStatementNarrative',
        "fx_ticket_id":'fxTicketID',
        "requested_fx":'requestedFX',
        "payer_type":'payerType',
        "payout_type":'payoutType',
        "transaction_hold":'transactionHold'
    }

    def __init__(self,
                 transaction_id=None,
                 payout_details=None,
                 payout_request_amount=None,
                 beneficiary_amount_information=None,
                 service_level=None,
                 beneficiary_statement_narrative=None,
                 fx_ticket_id=None,
                 requested_fx=None,
                 payer_type=None,
                 payout_type=None,
                 transaction_hold=None):
        """Constructor for the PaymentRegisteredBeneficiaryRequest class"""

        # Initialize members of the class
        self.transaction_id = transaction_id
        self.payout_request_amount = payout_request_amount
        self.beneficiary_amount_information = beneficiary_amount_information
        self.service_level = service_level
        self.beneficiary_statement_narrative = beneficiary_statement_narrative
        self.fx_ticket_id = fx_ticket_id
        self.requested_fx = requested_fx
        self.payer_type = payer_type
        self.payout_type = payout_type
        self.payout_details = payout_details
        self.transaction_hold = transaction_hold


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        transaction_id = earthport-rest-api-client.models.transaction_id_merchant.TransactionIDMerchant.from_dictionary(dictionary.get('transactionID')) if dictionary.get('transactionID') else None
        payout_details = None
        if dictionary.get('payoutDetails') != None:
            payout_details = list()
            for structure in dictionary.get('payoutDetails'):
                payout_details.append(earthport-rest-api-client.models.payout_details.PayoutDetails.from_dictionary(structure))
        payout_request_amount = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('payoutRequestAmount')) if dictionary.get('payoutRequestAmount') else None
        beneficiary_amount_information = earthport-rest-api-client.models.beneficiary_amount_information.BeneficiaryAmountInformation.from_dictionary(dictionary.get('beneficiaryAmountInformation')) if dictionary.get('beneficiaryAmountInformation') else None
        service_level = dictionary.get('serviceLevel')
        beneficiary_statement_narrative = dictionary.get('beneficiaryStatementNarrative')
        fx_ticket_id = dictionary.get('fxTicketID')
        requested_fx = dictionary.get('requestedFX')
        payer_type = dictionary.get('payerType')
        payout_type = dictionary.get('payoutType')
        transaction_hold = earthport-rest-api-client.models.transaction_hold.TransactionHold.from_dictionary(dictionary.get('transactionHold')) if dictionary.get('transactionHold') else None

        # Return an object of this model
        return cls(transaction_id,
                   payout_details,
                   payout_request_amount,
                   beneficiary_amount_information,
                   service_level,
                   beneficiary_statement_narrative,
                   fx_ticket_id,
                   requested_fx,
                   payer_type,
                   payout_type,
                   transaction_hold)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.identification

class IdentificationList(object):

    """Implementation of the 'IdentificationList' model.

    Represents a list of Identityfication objects.

    Attributes:
        identification (list of Identification): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "identification":'identification'
    }

    def __init__(self,
                 identification=None):
        """Constructor for the IdentificationList class"""

        # Initialize members of the class
        self.identification = identification


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        identification = None
        if dictionary.get('identification') != None:
            identification = list()
            for structure in dictionary.get('identification'):
                identification.append(earthport-rest-api-client.models.identification.Identification.from_dictionary(structure))

        # Return an object of this model
        return cls(identification)





# -*- coding: utf-8 -*-

class IdentityEntityEnum(object):

    """Implementation of the 'IdentityEntity' enum.

    Supported identity entity types.

    Attributes:
        INDIVIDUAL: TODO: type description here.
        LEGALENTITY: TODO: type description here.

    """

    INDIVIDUAL = 'individual'

    LEGALENTITY = 'legalEntity'




# -*- coding: utf-8 -*-


class BenBankIDMerchant(object):

    """Implementation of the 'BenBankID_Merchant' model.

    This group consists of merchant beneficiary bank identifier only.

    Attributes:
        merchant_bank_id (string): The merchant specified ID for a beneficiary
            bank account.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "merchant_bank_id":'merchantBankID'
    }

    def __init__(self,
                 merchant_bank_id=None):
        """Constructor for the BenBankIDMerchant class"""

        # Initialize members of the class
        self.merchant_bank_id = merchant_bank_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        merchant_bank_id = dictionary.get('merchantBankID')

        # Return an object of this model
        return cls(merchant_bank_id)





__all__ = [
    'base_controller',
    'quotes_controller',
    'balances_controller',
    'payments_controller',
    'beneficiary_bank_accounts_controller',
    'authentication_controller',
    'users_controller',
    'transactions_controller',
    'statements_controller',
    'settlement_calendars_controller',
]


# -*- coding: utf-8 -*-


class Address(object):

    """Implementation of the 'Address' model.

    Represents an address. Mandatory attributes are 'addressLine1', 'city' and
    'country'. All other attributes are optional.

    Attributes:
        address_line_1 (string): A line of address information. The length of
            this field is limited to 254 bytes. This value will be truncated
            if it is too long.
        address_line_2 (string): A line of address information. The length of
            this field is limited to 254 bytes. This value will be truncated
            if it is too long.
        address_line_3 (string): A line of address information. The length of
            this field is limited to 254 bytes. This value will be truncated
            if it is too long.
        city (string): A line of address information. The length of this field
            is limited to 254 bytes. This value will be truncated if it is too
            long.
        country (string): Valid supported ISO 3166 2-character country code.
        postcode (string): A line of address information. The length of this
            field is limited to 10 bytes. 10 bytes can hold 10 normal English
            characters. This value will be truncated if it is too long.
        province (string): A line of address information. The length of this
            field is limited to 254 bytes. This value will be truncated if it
            is too long.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "address_line1":'addressLine1',
        "city":'city',
        "country":'country',
        "address_line2":'addressLine2',
        "address_line3":'addressLine3',
        "postcode":'postcode',
        "province":'province'
    }

    def __init__(self,
                 address_line1=None,
                 city=None,
                 country=None,
                 address_line2=None,
                 address_line3=None,
                 postcode=None,
                 province=None):
        """Constructor for the Address class"""

        # Initialize members of the class
        self.address_line1 = address_line1
        self.address_line2 = address_line2
        self.address_line3 = address_line3
        self.city = city
        self.country = country
        self.postcode = postcode
        self.province = province


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        address_line1 = dictionary.get('addressLine1')
        city = dictionary.get('city')
        country = dictionary.get('country')
        address_line2 = dictionary.get('addressLine2')
        address_line3 = dictionary.get('addressLine3')
        postcode = dictionary.get('postcode')
        province = dictionary.get('province')

        # Return an object of this model
        return cls(address_line1,
                   city,
                   country,
                   address_line2,
                   address_line3,
                   postcode,
                   province)





# -*- coding: utf-8 -*-


class TransactionHold(object):

    """Implementation of the 'TransactionHold' model.

    Parameter to prevent transactions from being processed until the desired
    time has been reached Note releaseDateTime must be in UTC format.

    Attributes:
        offset_minutes (int): TODO: type description here.
        release_date_time (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "offset_minutes":'offsetMinutes',
        "release_date_time":'releaseDateTime'
    }

    def __init__(self,
                 offset_minutes=None,
                 release_date_time=None):
        """Constructor for the TransactionHold class"""

        # Initialize members of the class
        self.offset_minutes = offset_minutes
        self.release_date_time = release_date_time


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        offset_minutes = dictionary.get('offsetMinutes')
        release_date_time = dictionary.get('releaseDateTime')

        # Return an object of this model
        return cls(offset_minutes,
                   release_date_time)





# -*- coding: utf-8 -*-


class TransactionID(object):

    """Implementation of the 'TransactionID' model.

    Transaction ID type which contains both the unique Earthport transaction
    ID and the merchant supplied transaction ID.

    Attributes:
        ep_transaction_id (long|int): The payment ID generated by EPS.
        merchant_transaction_id (string): The unique reference of a
            transaction provided by the merchant.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "ep_transaction_id":'epTransactionID',
        "merchant_transaction_id":'merchantTransactionID'
    }

    def __init__(self,
                 ep_transaction_id=None,
                 merchant_transaction_id=None):
        """Constructor for the TransactionID class"""

        # Initialize members of the class
        self.ep_transaction_id = ep_transaction_id
        self.merchant_transaction_id = merchant_transaction_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        ep_transaction_id = dictionary.get('epTransactionID')
        merchant_transaction_id = dictionary.get('merchantTransactionID')

        # Return an object of this model
        return cls(ep_transaction_id,
                   merchant_transaction_id)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.monetary_value

class BeneficiaryAmountInformation(object):

    """Implementation of the 'BeneficiaryAmountInformation' model.

    Used to specify the beneficiary amount and the payout currency.

    Attributes:
        beneficiary_amount (MonetaryValue): Represents a monetary value
            containing a decimal amount value along with a currency code. The
            currency code is a three letter ISO 4217 code. E.g. GBP for
            British sterling pounds.
        payout_currency (string): Valid supported ISO 4217 3-character
            currency code.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "beneficiary_amount":'beneficiaryAmount',
        "payout_currency":'payoutCurrency'
    }

    def __init__(self,
                 beneficiary_amount=None,
                 payout_currency=None):
        """Constructor for the BeneficiaryAmountInformation class"""

        # Initialize members of the class
        self.beneficiary_amount = beneficiary_amount
        self.payout_currency = payout_currency


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        beneficiary_amount = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('beneficiaryAmount')) if dictionary.get('beneficiaryAmount') else None
        payout_currency = dictionary.get('payoutCurrency')

        # Return an object of this model
        return cls(beneficiary_amount,
                   payout_currency)





# -*- coding: utf-8 -*-

import requests

from cachecontrol import CacheControl
from requests.adapters import HTTPAdapter
from requests.packages.urllib3.util.retry import Retry

from .http_client import HttpClient
from .http_response import HttpResponse
from .http_method_enum import HttpMethodEnum


class RequestsClient(HttpClient):

    """An implementation of HttpClient that uses Requests as its HTTP Client

    Attributes:
        timeout (int): The default timeout for all API requests.

    """

    def __init__(self, timeout=60, cache=False, max_retries=None, retry_interval=None):
        """The constructor.

        Args:
            timeout (float): The default global timeout(seconds).

        """
        self.timeout = timeout
        self.session = requests.session()

        if max_retries and retry_interval:
            retries = Retry(total=max_retries, backoff_factor=retry_interval)
            self.session.mount('http://', HTTPAdapter(max_retries=retries))
            self.session.mount('https://', HTTPAdapter(max_retries=retries))

        if cache:
            self.session = CacheControl(self.session)

    def execute_as_string(self, request):
        """Execute a given HttpRequest to get a string response back

        Args:
            request (HttpRequest): The given HttpRequest to execute.

        Returns:
            HttpResponse: The response of the HttpRequest.

        """
        response = self.session.request(HttpMethodEnum.to_string(request.http_method),
                                        request.query_url,
                                        headers=request.headers,
                                        params=request.query_parameters,
                                        data=request.parameters,
                                        files=request.files,
                                        timeout=self.timeout)

        return self.convert_response(response, False)

    def execute_as_binary(self, request):
        """Execute a given HttpRequest to get a binary response back

        Args:
            request (HttpRequest): The given HttpRequest to execute.

        Returns:
            HttpResponse: The response of the HttpRequest.

        """
        response = self.session.request(HttpMethodEnum.to_string(request.http_method),
                                        request.query_url,
                                        headers=request.headers,
                                        params=request.query_parameters,
                                        data=request.parameters,
                                        files=request.files,
                                        timeout=self.timeout)

        return self.convert_response(response, True)

    def convert_response(self, response, binary):
        """Converts the Response object of the HttpClient into an
        HttpResponse object.

        Args:
            response (dynamic): The original response object.

        Returns:
            HttpResponse: The converted HttpResponse object.

        """
        if binary:
            return HttpResponse(response.status_code, response.headers, response.content)
        else:
            return HttpResponse(response.status_code, response.headers, response.text)



__all__ = [
    'identity',
    'individual_identity',
    'legal_entity_identity',
    'unstructured_identity',
    'additional_data',
    'address',
    'birth_information',
    'identification',
    'individual_name',
    'legal_entity_registration',
    'bank_account_details',
    'payout_details',
    'monetary_value',
    'transaction_hold',
    'users_bank_id',
    'ben_bank_id',
    'ben_bank_id_merchant',
    'user_id',
    'user_id_merchant',
    'transaction_id',
    'transaction_id_merchant',
    'payout_response',
    'fx_rate',
    'beneficiary_amount_information',
    'statement_detail',
    'financial_transaction_status',
    'fx_executed_rate',
    'fx_detail',
    'fx_ticket_id',
    'account_balance',
    'financial_transaction',
    'payout_transaction_short',
    'user_deposit_transaction',
    'merchant_liquidity_movement_transaction',
    'liquidity_deposit_transaction',
    'journal_transaction',
    'earthport_merchant_liquidity_transfer',
    'generic_transaction',
    'statement',
    'statement_line_item',
    'pagination_result',
    'access_token_response',
    'settlement_calendar',
    'beneficiary_bank_account_field',
    'beneficiary_bank_account_fields_list',
    'beneficiary_bank_account_group',
    'beneficiary_bank_account_groups_list',
    'beneficiary_bank_account_list_item',
    'beneficiary_bank_account_list_items',
    'beneficiary_additional_data_list',
    'beneficiary_additional_data',
    'identification_list',
    'payer_additional_data_list',
    'payer_additional_data',
    'beneficiary_identity_field_group_choice',
    'beneficiary_identity_field',
    'beneficiary_identity_fields_list',
    'beneficiary_identity_group',
    'beneficiary_identity_groups_list',
    'beneficiary_identity_list_item',
    'beneficiary_identity_list_items',
    'additional_field_with_validator',
    'additional_field_with_values',
    'additional_fields_list',
    'identity_restriction',
    'purpose_of_payment_code',
    'purpose_of_payment_field_groups_list',
    'purpose_of_payment_usage_restrictions',
    'get_payout_required_data_response',
    'get_payout_required_data_for_bank',
    'get_payout_required_data_for_country_currency',
    'add_deposit_reference_request',
    'bank_account',
    'beneficiary_bank_account_summary',
    'bulk_fx_detail',
    'cancel_transaction_response',
    'create_bulk_fx_quote_response',
    'create_fx_quote_response',
    'create_beneficiary_bank_account_request',
    'create_bulk_fx_quote_request',
    'create_fx_quote_request',
    'create_payment_request',
    'create_validate_user_request',
    'field_value',
    'get_beneficiary_bank_account_response',
    'get_expected_settlement_date_response',
    'get_indicative_fx_quote_response',
    'get_settlement_calendar_response',
    'get_user_response',
    'get_expected_settlement_date_request',
    'get_indicative_fx_quote_request',
    'list_bank_accounts_response',
    'payment',
    'payment_registered_beneficiary_request',
    'search_transactions_response',
    'update_user_request',
    'user',
    'validate_beneficiary_bank_account_response',
    'validate_beneficiary_bank_account_request',
    'payer_type_enum',
    'requested_fx_enum',
    'service_level_enum',
    'fx_method_enum',
    'money_movement_type_enum',
    'additional_information_enum',
    'beneficiary_bank_account_field_input_enum',
    'beneficiary_bank_account_status_enum',
    'beneficiary_identity_field_input_enum',
    'identity_entity_enum',
    'action_enum',
    'beneficiary_identity_entity_type_enum',
    'grant_type_enum',
    'id_type_enum',
    'sort_order_enum',
    'transaction_type_enum',
]


# -*- coding: utf-8 -*-


class UserIDMerchant(object):

    """Implementation of the 'UserID_Merchant' model.

    This group consists of merchant user identifier only.

    Attributes:
        merchant_user_id (string): A unique reference for the merchant that
            identifies the person or company on behalf of which this account
            was set up. This needs to be used to reference KYC data held by
            the merchant (amongst other things). This is often a unique
            username or reference allocated by the merchant at user
            registration time.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "merchant_user_id":'merchantUserID'
    }

    def __init__(self,
                 merchant_user_id=None):
        """Constructor for the UserIDMerchant class"""

        # Initialize members of the class
        self.merchant_user_id = merchant_user_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        merchant_user_id = dictionary.get('merchantUserID')

        # Return an object of this model
        return cls(merchant_user_id)





# -*- coding: utf-8 -*-


class ValidateBeneficiaryBankAccountResponse(object):

    """Implementation of the 'Validate Beneficiary Bank AccountResponse' model.

    This is the response to the Validate Beneficiary Bank Account API.

    Attributes:
        is_bank_account_valid (bool): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "is_bank_account_valid":'isBankAccountValid'
    }

    def __init__(self,
                 is_bank_account_valid=None):
        """Constructor for the ValidateBeneficiaryBankAccountResponse class"""

        # Initialize members of the class
        self.is_bank_account_valid = is_bank_account_valid


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        is_bank_account_valid = dictionary.get('isBankAccountValid')

        # Return an object of this model
        return cls(is_bank_account_valid)





# -*- coding: utf-8 -*-

class HttpResponse(object):

    """Information about an HTTP Response including its status code, returned
        headers, and raw body

    Attributes:
        status_code (int): The status code response from the server that
            corresponds to this response.
        headers (dict): A dictionary of headers (key : value) that were
            returned with the response
        raw_body (string): The Raw body of the HTTP Response as a string

    """

    def __init__(self,
                 status_code,
                 headers,
                 raw_body):
        """Constructor for the HttpResponse class

        Args:
            status_code (int): The response status code.
            headers (dict): The response headers.
            raw_body (string): The raw body from the server.

        """
        self.status_code = status_code
        self.headers = headers
        self.raw_body = raw_body



# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.monetary_value

class CreateFXQuoteRequest(object):

    """Implementation of the 'CreateFXQuoteRequest' model.

    TODO: type model description here.

    Attributes:
        sell_amount (MonetaryValue): Represents a monetary value containing a
            decimal amount value along with a currency code. The currency code
            is a three letter ISO 4217 code. E.g. GBP for British sterling
            pounds.
        buy_currency (string): Valid supported ISO 4217 3-character currency
            code.
        buy_amount (MonetaryValue): Represents a monetary value containing a
            decimal amount value along with a currency code. The currency code
            is a three letter ISO 4217 code. E.g. GBP for British sterling
            pounds.
        sell_currency (string): Valid supported ISO 4217 3-character currency
            code.
        service_level (ServiceLevelEnum): Supported service levels for a
            payout request (standard or express).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "sell_amount":'sellAmount',
        "buy_currency":'buyCurrency',
        "buy_amount":'buyAmount',
        "sell_currency":'sellCurrency',
        "service_level":'serviceLevel'
    }

    def __init__(self,
                 sell_amount=None,
                 buy_currency=None,
                 buy_amount=None,
                 sell_currency=None,
                 service_level=None):
        """Constructor for the CreateFXQuoteRequest class"""

        # Initialize members of the class
        self.sell_amount = sell_amount
        self.buy_currency = buy_currency
        self.buy_amount = buy_amount
        self.sell_currency = sell_currency
        self.service_level = service_level


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        sell_amount = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('sellAmount')) if dictionary.get('sellAmount') else None
        buy_currency = dictionary.get('buyCurrency')
        buy_amount = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('buyAmount')) if dictionary.get('buyAmount') else None
        sell_currency = dictionary.get('sellCurrency')
        service_level = dictionary.get('serviceLevel')

        # Return an object of this model
        return cls(sell_amount,
                   buy_currency,
                   buy_amount,
                   sell_currency,
                   service_level)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.monetary_value
import earthport-rest-api-client.models.fx_rate
import earthport-rest-api-client.models.fx_ticket_id

class FXExecutedRate(object):

    """Implementation of the 'FXExecutedRate' model.

    Holds details of an executed FX conversion that has occured as part of a
    financial transaction. The FX that occured was from the sellCurrency to
    the buyCurrency at a particular rate. The rate may have been requested via
    an FX Quote (fxTicketID). An FX conversion fee may have been applied to
    certain transaction types.

    Attributes:
        fx_fee_amount (MonetaryValue): Represents a monetary value containing
            a decimal amount value along with a currency code. The currency
            code is a three letter ISO 4217 code. E.g. GBP for British
            sterling pounds.
        fx_rate (FXRate): Represents an FX rate between two currencies, the
            rate is restricted to 6 decimal places. The currency code is a
            three letter ISO 4217 code. E.g. GBP for British sterling pounds.
        fx_ticket_id (FXTicketID): The unique FX Ticket ID generated by the
            Earthport payment system.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "fx_rate":'fxRate',
        "fx_fee_amount":'fxFeeAmount',
        "fx_ticket_id":'fxTicketID'
    }

    def __init__(self,
                 fx_rate=None,
                 fx_fee_amount=None,
                 fx_ticket_id=None):
        """Constructor for the FXExecutedRate class"""

        # Initialize members of the class
        self.fx_fee_amount = fx_fee_amount
        self.fx_rate = fx_rate
        self.fx_ticket_id = fx_ticket_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        fx_rate = earthport-rest-api-client.models.fx_rate.FXRate.from_dictionary(dictionary.get('fxRate')) if dictionary.get('fxRate') else None
        fx_fee_amount = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('fxFeeAmount')) if dictionary.get('fxFeeAmount') else None
        fx_ticket_id = earthport-rest-api-client.models.fx_ticket_id.FXTicketID.from_dictionary(dictionary.get('fxTicketID')) if dictionary.get('fxTicketID') else None

        # Return an object of this model
        return cls(fx_rate,
                   fx_fee_amount,
                   fx_ticket_id)





# -*- coding: utf-8 -*-

from ..api_helper import APIHelper
from ..http.http_context import HttpContext
from ..http.requests_client import RequestsClient
from ..exceptions.api_exception import APIException

class BaseController(object):

    """All controllers inherit from this base class.

    Attributes:
        http_client (HttpClient): The HttpClient which a specific controller
            instance will use. By default all the controller objects share
            the same HttpClient. A user can use his own custom HttpClient
            as well.
        http_call_back (HttpCallBack): An object which holds call back
            methods to be called before and after the execution of an HttpRequest.
        global_headers (dict): The global headers of the API which are sent with
            every request.

    """

    http_client = RequestsClient()

    http_call_back = None

    global_headers = {

    }

    def __init__(self, client=None, call_back=None):
        if client != None:
            self.http_client = client
        if call_back != None:
            self.http_call_back = call_back

    def validate_parameters(self, **kwargs):
        """Validates required parameters of an endpoint.

        Args:
            kwargs (dict): A dictionary of the required parameters.

        """
        for name, value in kwargs.items():
            if value is None:
                raise ValueError("Required parameter {} cannot be None.".format(name))

    def execute_request(self, request, binary=False):
        """Executes an HttpRequest.

        Args:
            request (HttpRequest): The HttpRequest to execute.
            binary (bool): A flag which should be set to True if
                a binary response is expected.

        Returns:
            HttpContext: The HttpContext of the request. It contains,
                both, the request itself and the HttpResponse object.

        """
        # Invoke the on before request HttpCallBack if specified
        if self.http_call_back != None:
            self.http_call_back.on_before_request(request)

        # Add global headers to request
        request.headers = APIHelper.merge_dicts(self.global_headers, request.headers)

        # Invoke the API call to fetch the response.
        func = self.http_client.execute_as_binary if binary else self.http_client.execute_as_string
        response = func(request)
        context = HttpContext(request, response)

        # Invoke the on after response HttpCallBack if specified
        if self.http_call_back != None:
            self.http_call_back.on_after_response(context)

        return context

    def validate_response(self, context):
        """Validates an HTTP response by checking for global errors.

        Args:
            context (HttpContext): The HttpContext of the API call.

        """
        if (context.response.status_code < 200) or (context.response.status_code > 208): #[200,208] = HTTP OK
            raise APIException('HTTP response not OK.', context)



# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.settlement_calendar

class GetSettlementCalendarResponse(object):

    """Implementation of the 'Get Settlement CalendarResponse' model.

    Settlement Calendar.

    Attributes:
        response_time_stamp (string): TODO: type description here.
        settlement_calendar (list of SettlementCalendar): TODO: type
            description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "response_time_stamp":'responseTimeStamp',
        "settlement_calendar":'settlementCalendar'
    }

    def __init__(self,
                 response_time_stamp=None,
                 settlement_calendar=None):
        """Constructor for the GetSettlementCalendarResponse class"""

        # Initialize members of the class
        self.response_time_stamp = response_time_stamp
        self.settlement_calendar = settlement_calendar


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        response_time_stamp = dictionary.get('responseTimeStamp')
        settlement_calendar = None
        if dictionary.get('settlementCalendar') != None:
            settlement_calendar = list()
            for structure in dictionary.get('settlementCalendar'):
                settlement_calendar.append(earthport-rest-api-client.models.settlement_calendar.SettlementCalendar.from_dictionary(structure))

        # Return an object of this model
        return cls(response_time_stamp,
                   settlement_calendar)





# -*- coding: utf-8 -*-

class MoneyMovementTypeEnum(object):

    """Implementation of the 'MoneyMovementType' enum.

    Specifies whether a money movement is a debit or credit

    Attributes:
        DEBIT: TODO: type description here.
        CREDIT: TODO: type description here.

    """

    DEBIT = 'Debit'

    CREDIT = 'Credit'




# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.user_id
import earthport-rest-api-client.models.ben_bank_id

class UsersBankID(object):

    """Implementation of the 'UsersBankID' model.

    This group consists of a collection of both the user ID group and
    beneficiary bank ID group. The 'userID' is a collection of user identifier
    types. The 'benBankID' is a collection of account identifier types. Both
    the 'userID' and 'benBankID' fields are mandatory.

    Attributes:
        user_id (UserID): This group consists of all possible user identifier
            types. The 'epUserID' field is a unique identifier for a merchant
            and is the equivalent of a Virtual Account Number (VAN). The
            'merchantUserID' is a merchant specified identifier for an
            individual or company that an account was set up for. The
            'epUserID', 'merchantUserID' or both 'epUserID' and
            'merchantUserID' can be supplied. A mapping will be performed to
            retrieve the merchant user ID from the supplied EP user ID and
            vice versa. If both the 'epUserID' and 'merchantUserID' are
            supplied, a check will be performed to ensure that the two are
            mapped. If the two provided fields are not mapped, then a
            validation error code will be returned. At least one of the fields
            must be populated.
        ben_bank_id (BenBankID): This group consists of all possible
            beneficiary bank identifier types. The 'epBankID' field is a
            unique identifier for a beneficiary bank account. The
            'merchantBankID' is an optional merchant specified identifier for
            the beneficiary bank account. The 'epBankID', 'merchantBankID' or
            both 'epBankID' and 'merchantBankID' can be supplied. A mapping
            will be performed to retrieve the merchant bank ID from the
            supplied EP bank ID and vice versa. If both the 'epBankID' and
            'merchantBankID' are supplied, a check will be performed to ensure
            that the two are mapped. If the two provided fields are not
            mapped, then a validation error code will be returned. At least
            one of the fields must be populated.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "user_id":'userID',
        "ben_bank_id":'benBankID'
    }

    def __init__(self,
                 user_id=None,
                 ben_bank_id=None):
        """Constructor for the UsersBankID class"""

        # Initialize members of the class
        self.user_id = user_id
        self.ben_bank_id = ben_bank_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        user_id = earthport-rest-api-client.models.user_id.UserID.from_dictionary(dictionary.get('userID')) if dictionary.get('userID') else None
        ben_bank_id = earthport-rest-api-client.models.ben_bank_id.BenBankID.from_dictionary(dictionary.get('benBankID')) if dictionary.get('benBankID') else None

        # Return an object of this model
        return cls(user_id,
                   ben_bank_id)





# -*- coding: utf-8 -*-

from .base_controller import BaseController
from ..api_helper import APIHelper
from ..configuration import Configuration
from ..http.auth.custom_header_auth import CustomHeaderAuth
from ..models.get_expected_settlement_date_response import GetExpectedSettlementDateResponse
from ..models.validate_beneficiary_bank_account_response import ValidateBeneficiaryBankAccountResponse
from ..models.users_bank_id import UsersBankID
from ..models.list_bank_accounts_response import ListBankAccountsResponse
from ..models.get_beneficiary_bank_account_response import GetBeneficiaryBankAccountResponse
from ..exceptions.api_exception import APIException

class BeneficiaryBankAccountsController(BaseController):

    """A Controller to access Endpoints in the earthport-rest-api-client API."""


    def create_get_expected_settlement_date(self,
                                            get_expected_settlement_date_request):
        """Does a POST request to /bank-accounts/expected-settlement.

        Vaidates a new beneficiary bank account and get expected settlement
        date.

        Args:
            get_expected_settlement_date_request
                (GetExpectedSettlementDateRequest): The beneficiary bank
                account.

        Returns:
            GetExpectedSettlementDateResponse: Response from the API. Bank
                Account Valid.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/bank-accounts/expected-settlement'
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(get_expected_settlement_date_request))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetExpectedSettlementDateResponse.from_dictionary)

    def create_validate_beneficiary_bank_account(self,
                                                 validate_beneficiary_bank_account_request):
        """Does a POST request to /bank-accounts.

        Vaidates a new beneficiary bank account against a User.

        Args:
            validate_beneficiary_bank_account_request
                (ValidateBeneficiaryBankAccountRequest): The beneficiary bank
                account.

        Returns:
            ValidateBeneficiaryBankAccountResponse: Response from the API.
                Bank Account Valid.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/bank-accounts'
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(validate_beneficiary_bank_account_request))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ValidateBeneficiaryBankAccountResponse.from_dictionary)

    def create_beneficiary_bank_account(self,
                                        create_beneficiary_bank_account_request,
                                        user_id,
                                        id_type=None):
        """Does a POST request to /users/{userID}/bank-accounts.

        Registers a new beneficiary bank account against a User.

        Args:
            create_beneficiary_bank_account_request
                (CreateBeneficiaryBankAccountRequest): The beneficiary bank
                account.
            user_id (string): The payer's unique id. It can be either VAN or
                merchant id.
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            UsersBankID: Response from the API. Bank Account succesfully
                created.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/users/{userID}/bank-accounts'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'userID': user_id
        })
        _query_parameters = {
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_beneficiary_bank_account_request))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, UsersBankID.from_dictionary)

    def list_bank_accounts(self,
                           user_id,
                           offset=None,
                           page_size=None,
                           id_type=None):
        """Does a GET request to /users/{userID}/bank-accounts.

        Gets all Beneficiary Bank Accounts registered by this User.

        Args:
            user_id (string): The payer's unique id. It can be either VAN or
                merchant id.
            offset (int, optional): This is used for pagination of resultsets.
                0-based starting offset of the page with respect to the entire
                resultset.
            page_size (int, optional): This is used for pagination of
                resultsets. Number of items per page to return. If empty the
                maximum allowable (25) number of records will be returned.
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            ListBankAccountsResponse: Response from the API. Bank Accounts
                succesfully returned.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/users/{userID}/bank-accounts'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'userID': user_id
        })
        _query_parameters = {
            'offset': offset,
            'pageSize': page_size,
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ListBankAccountsResponse.from_dictionary)

    def get_beneficiary_bank_account(self,
                                     user_id,
                                     bank_id,
                                     id_type=None):
        """Does a GET request to /users/{userID}/bank-accounts/{bankID}.

        Gets a Beneficiary Bank Account.

        Args:
            user_id (string): The payer's unique id. It can be either VAN or
                merchant id.
            bank_id (string): Unique ID for the beneficiary bank account. It
                can be either earthport id or merchant id.
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            GetBeneficiaryBankAccountResponse: Response from the API. Bank
                Accounts succesfully returned.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/users/{userID}/bank-accounts/{bankID}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'userID': user_id,
            'bankID': bank_id
        })
        _query_parameters = {
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetBeneficiaryBankAccountResponse.from_dictionary)

    def delete_deactivate_beneficiary_bank_account(self,
                                                   user_id,
                                                   bank_id,
                                                   id_type=None):
        """Does a DELETE request to /users/{userID}/bank-accounts/{bankID}.

        Deactivates a Beneficiary Bank Account. You will not be able to send a
        payment to a deactivated bank account.

        Args:
            user_id (string): The payer's unique id. It can be either VAN or
                merchant id.
            bank_id (string): Unique ID for the beneficiary bank account. It
                can be either earthport id or merchant id.
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            void: Response from the API. Bank Accounts succesfully
                deactivated.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/users/{userID}/bank-accounts/{bankID}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'userID': user_id,
            'bankID': bank_id
        })
        _query_parameters = {
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.delete(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)



# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.financial_transaction
import earthport-rest-api-client.models.pagination_result

class SearchTransactionsResponse(object):

    """Implementation of the 'Search TransactionsResponse' model.

    Transactions.

    Attributes:
        transactions (list of FinancialTransaction): TODO: type description
            here.
        pagination_result (PaginationResult): This returns a paged set of
            results rather than the full result set.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "transactions":'transactions',
        "pagination_result":'paginationResult'
    }

    def __init__(self,
                 transactions=None,
                 pagination_result=None):
        """Constructor for the SearchTransactionsResponse class"""

        # Initialize members of the class
        self.transactions = transactions
        self.pagination_result = pagination_result


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        transactions = None
        if dictionary.get('transactions') != None:
            transactions = list()
            for structure in dictionary.get('transactions'):
                transactions.append(earthport-rest-api-client.models.financial_transaction.FinancialTransaction.from_dictionary(structure))
        pagination_result = earthport-rest-api-client.models.pagination_result.PaginationResult.from_dictionary(dictionary.get('paginationResult')) if dictionary.get('paginationResult') else None

        # Return an object of this model
        return cls(transactions,
                   pagination_result)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.identity
import earthport-rest-api-client.models.bank_account_details
import earthport-rest-api-client.models.payout_details
import earthport-rest-api-client.models.transaction_hold

class GetExpectedSettlementDateRequest(object):

    """Implementation of the 'GetExpectedSettlementDateRequest' model.

    The beneficiary bank account Object.

    Attributes:
        beneficiary_identity (Identity): Represents the identity of an
            individual or legal entity. You must specify one of either an
            individual identity or legal entity identity or unstructured
            identity.
        description (string): Type which defines a beneficiary bank account
            description. Each bank account must be given a description
            therefore this is a mandatory component of the
            BeneficiaryBankAccount complex type.
        country_code (string): Valid supported ISO 3166 2-character country
            code.
        currency_code (string): Valid supported ISO 4217 3-character currency
            code.
        payout_request_currency (string): Valid supported ISO 4217 3-character
            currency code.
        anticipated_payout_request_time (string): Valid ISO 8601 date format
            YYYY-MM-DD.
        bank_account_details (list of BankAccountDetails): TODO: type
            description here.
        payer_identity (Identity): Represents the identity of an individual or
            legal entity. You must specify one of either an individual
            identity or legal entity identity or unstructured identity.
        service_level (ServiceLevelEnum): Supported service levels for a
            payout request (standard or express).
        payer_type (PayerTypeEnum): The type of Payer making the payment. This
            detrmines which identity details are used as the payer identity.
        payout_details (list of PayoutDetails): TODO: type description here.
        transaction_hold (TransactionHold): Parameter to prevent transactions
            from being processed until the desired time has been reached Note
            releaseDateTime must be in UTC format.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "beneficiary_identity":'beneficiaryIdentity',
        "description":'description',
        "country_code":'countryCode',
        "anticipated_payout_request_time":'anticipatedPayoutRequestTime',
        "bank_account_details":'bankAccountDetails',
        "payout_details":'payoutDetails',
        "currency_code":'currencyCode',
        "payout_request_currency":'payoutRequestCurrency',
        "payer_identity":'payerIdentity',
        "service_level":'serviceLevel',
        "payer_type":'payerType',
        "transaction_hold":'transactionHold'
    }

    def __init__(self,
                 beneficiary_identity=None,
                 description=None,
                 country_code=None,
                 anticipated_payout_request_time=None,
                 bank_account_details=None,
                 payout_details=None,
                 currency_code=None,
                 payout_request_currency=None,
                 payer_identity=None,
                 service_level=None,
                 payer_type=None,
                 transaction_hold=None):
        """Constructor for the GetExpectedSettlementDateRequest class"""

        # Initialize members of the class
        self.beneficiary_identity = beneficiary_identity
        self.description = description
        self.country_code = country_code
        self.currency_code = currency_code
        self.payout_request_currency = payout_request_currency
        self.anticipated_payout_request_time = anticipated_payout_request_time
        self.bank_account_details = bank_account_details
        self.payer_identity = payer_identity
        self.service_level = service_level
        self.payer_type = payer_type
        self.payout_details = payout_details
        self.transaction_hold = transaction_hold


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        beneficiary_identity = earthport-rest-api-client.models.identity.Identity.from_dictionary(dictionary.get('beneficiaryIdentity')) if dictionary.get('beneficiaryIdentity') else None
        description = dictionary.get('description')
        country_code = dictionary.get('countryCode')
        anticipated_payout_request_time = dictionary.get('anticipatedPayoutRequestTime')
        bank_account_details = None
        if dictionary.get('bankAccountDetails') != None:
            bank_account_details = list()
            for structure in dictionary.get('bankAccountDetails'):
                bank_account_details.append(earthport-rest-api-client.models.bank_account_details.BankAccountDetails.from_dictionary(structure))
        payout_details = None
        if dictionary.get('payoutDetails') != None:
            payout_details = list()
            for structure in dictionary.get('payoutDetails'):
                payout_details.append(earthport-rest-api-client.models.payout_details.PayoutDetails.from_dictionary(structure))
        currency_code = dictionary.get('currencyCode')
        payout_request_currency = dictionary.get('payoutRequestCurrency')
        payer_identity = earthport-rest-api-client.models.identity.Identity.from_dictionary(dictionary.get('payerIdentity')) if dictionary.get('payerIdentity') else None
        service_level = dictionary.get('serviceLevel')
        payer_type = dictionary.get('payerType')
        transaction_hold = earthport-rest-api-client.models.transaction_hold.TransactionHold.from_dictionary(dictionary.get('transactionHold')) if dictionary.get('transactionHold') else None

        # Return an object of this model
        return cls(beneficiary_identity,
                   description,
                   country_code,
                   anticipated_payout_request_time,
                   bank_account_details,
                   payout_details,
                   currency_code,
                   payout_request_currency,
                   payer_identity,
                   service_level,
                   payer_type,
                   transaction_hold)





# -*- coding: utf-8 -*-


class Identification(object):

    """Implementation of the 'Identification' model.

    This group consists of an individual identification type unique number and
    the country of origin of the identification. The idType will be a String
    value saying what the identification number relates to. This might be
    Passport. national ID card, driving licence or any other value. The idType
    will be validated against an enumeration to ensure it is of a valid type.
    Please refer to the "API Solution Guide" for further details. The
    identification number will normally be the equivalent of a passport
    number, but other types of identification can be used. The identification
    country will be the country that issued the identification number, so in
    the example that a passport number is provided as the identification
    number, the identification country will be the passport country origin.

    Attributes:
        id_type (string): Enumeration of ID Types such as 'Passport', 'Driving
            License', 'National ID Card'. Please refer to the Earthport "API
            Solution Guide".
        identification_country (string): Valid supported ISO 3166 2-character
            country code.
        identification_number (string): An identification number for an
            individual. For example, a passport number can be an
            identification number type. The length of this field is limited to
            50 bytes. 50 bytes can hold 50 normal English characters. This
            value will be truncated if it is too long.
        valid_from_date (string): Valid ISO 8601 date format YYYY-MM-DD.
        valid_to_date (string): Valid ISO 8601 date format YYYY-MM-DD.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id_type":'idType',
        "identification_country":'identificationCountry',
        "identification_number":'identificationNumber',
        "valid_from_date":'validFromDate',
        "valid_to_date":'validToDate'
    }

    def __init__(self,
                 id_type=None,
                 identification_country=None,
                 identification_number=None,
                 valid_from_date=None,
                 valid_to_date=None):
        """Constructor for the Identification class"""

        # Initialize members of the class
        self.id_type = id_type
        self.identification_country = identification_country
        self.identification_number = identification_number
        self.valid_from_date = valid_from_date
        self.valid_to_date = valid_to_date


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id_type = dictionary.get('idType')
        identification_country = dictionary.get('identificationCountry')
        identification_number = dictionary.get('identificationNumber')
        valid_from_date = dictionary.get('validFromDate')
        valid_to_date = dictionary.get('validToDate')

        # Return an object of this model
        return cls(id_type,
                   identification_country,
                   identification_number,
                   valid_from_date,
                   valid_to_date)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.fx_detail

class GetIndicativeFXQuoteResponse(object):

    """Implementation of the 'Get Indicative FX QuoteResponse' model.

    TODO: type model description here.

    Attributes:
        fx_detail (FXDetail): Represents the details of an FX transaction,
            encapsulating the sellAmount, buyAmount and fxRate into a single
            type.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "fx_detail":'fxDetail'
    }

    def __init__(self,
                 fx_detail=None):
        """Constructor for the GetIndicativeFXQuoteResponse class"""

        # Initialize members of the class
        self.fx_detail = fx_detail


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        fx_detail = earthport-rest-api-client.models.fx_detail.FXDetail.from_dictionary(dictionary.get('fxDetail')) if dictionary.get('fxDetail') else None

        # Return an object of this model
        return cls(fx_detail)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.user_id
import earthport-rest-api-client.models.identity

class GetUserResponse(object):

    """Implementation of the 'Get UserResponse' model.

    A user Object.

    Attributes:
        user_id (UserID): This group consists of all possible user identifier
            types. The 'epUserID' field is a unique identifier for a merchant
            and is the equivalent of a Virtual Account Number (VAN). The
            'merchantUserID' is a merchant specified identifier for an
            individual or company that an account was set up for. The
            'epUserID', 'merchantUserID' or both 'epUserID' and
            'merchantUserID' can be supplied. A mapping will be performed to
            retrieve the merchant user ID from the supplied EP user ID and
            vice versa. If both the 'epUserID' and 'merchantUserID' are
            supplied, a check will be performed to ensure that the two are
            mapped. If the two provided fields are not mapped, then a
            validation error code will be returned. At least one of the fields
            must be populated.
        payer_identity (Identity): Represents the identity of an individual or
            legal entity. You must specify one of either an individual
            identity or legal entity identity or unstructured identity.
        created_date (string): Valid ISO 8601 date format YYYY-MM-DD.
        expired_date (string): Valid ISO 8601 date format YYYY-MM-DD.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "user_id":'userID',
        "payer_identity":'payerIdentity',
        "created_date":'createdDate',
        "expired_date":'expiredDate'
    }

    def __init__(self,
                 user_id=None,
                 payer_identity=None,
                 created_date=None,
                 expired_date=None):
        """Constructor for the GetUserResponse class"""

        # Initialize members of the class
        self.user_id = user_id
        self.payer_identity = payer_identity
        self.created_date = created_date
        self.expired_date = expired_date


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        user_id = earthport-rest-api-client.models.user_id.UserID.from_dictionary(dictionary.get('userID')) if dictionary.get('userID') else None
        payer_identity = earthport-rest-api-client.models.identity.Identity.from_dictionary(dictionary.get('payerIdentity')) if dictionary.get('payerIdentity') else None
        created_date = dictionary.get('createdDate')
        expired_date = dictionary.get('expiredDate')

        # Return an object of this model
        return cls(user_id,
                   payer_identity,
                   created_date,
                   expired_date)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.user_id_merchant
import earthport-rest-api-client.models.identity

class User(object):

    """Implementation of the 'User' model.

    A user Object.

    Attributes:
        user_id (UserIDMerchant): This group consists of merchant user
            identifier only.
        managed_merchant_identity (string): Refers to the descriptive name
            used to identify a given merchant. It is unique across Earthport
            merchants.
        account_currency (string): Valid supported ISO 4217 3-character
            currency code.
        payer_identity (Identity): Represents the identity of an individual or
            legal entity. You must specify one of either an individual
            identity or legal entity identity or unstructured identity.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "payer_identity":'payerIdentity',
        "user_id":'userID',
        "managed_merchant_identity":'managedMerchantIdentity',
        "account_currency":'accountCurrency'
    }

    def __init__(self,
                 payer_identity=None,
                 user_id=None,
                 managed_merchant_identity=None,
                 account_currency=None):
        """Constructor for the User class"""

        # Initialize members of the class
        self.user_id = user_id
        self.managed_merchant_identity = managed_merchant_identity
        self.account_currency = account_currency
        self.payer_identity = payer_identity


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        payer_identity = earthport-rest-api-client.models.identity.Identity.from_dictionary(dictionary.get('payerIdentity')) if dictionary.get('payerIdentity') else None
        user_id = earthport-rest-api-client.models.user_id_merchant.UserIDMerchant.from_dictionary(dictionary.get('userID')) if dictionary.get('userID') else None
        managed_merchant_identity = dictionary.get('managedMerchantIdentity')
        account_currency = dictionary.get('accountCurrency')

        # Return an object of this model
        return cls(payer_identity,
                   user_id,
                   managed_merchant_identity,
                   account_currency)





# -*- coding: utf-8 -*-

class BeneficiaryBankAccountFieldInputEnum(object):

    """Implementation of the 'BeneficiaryBankAccountFieldInput' enum.

    Supported input types for a bank registration UI.

    Attributes:
        TEXT: TODO: type description here.
        LIST: TODO: type description here.

    """

    TEXT = 'text'

    LIST = 'list'




# -*- coding: utf-8 -*-


class PaginationResult(object):

    """Implementation of the 'PaginationResult' model.

    This returns a paged set of results rather than the full result set.

    Attributes:
        offset (int): 0-based starting offset of the page with respect to the
            entire resultset.
        page_size (int): Number of items per page to return. If empty the
            maximum allowable (25) number of records will be returned.
        total_number_of_records (int): Total number of records in full result
            set.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "offset":'offset',
        "total_number_of_records":'totalNumberOfRecords',
        "page_size":'pageSize'
    }

    def __init__(self,
                 offset=None,
                 total_number_of_records=None,
                 page_size=None):
        """Constructor for the PaginationResult class"""

        # Initialize members of the class
        self.offset = offset
        self.page_size = page_size
        self.total_number_of_records = total_number_of_records


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        offset = dictionary.get('offset')
        total_number_of_records = dictionary.get('totalNumberOfRecords')
        page_size = dictionary.get('pageSize')

        # Return an object of this model
        return cls(offset,
                   total_number_of_records,
                   page_size)





# -*- coding: utf-8 -*-


class LegalEntityRegistration(object):

    """Implementation of the 'LegalEntityRegistration' model.

    This group consists of a legal entity registration number type and the
    country that the legal entity is registered in. Legal Entity Registration
    Number is mandatory Legal Entity Registration Country is mandatory Legal
    Entity Registration Province is optional.

    Attributes:
        legal_entity_registration_country (string): Valid supported ISO 3166
            2-character country code.
        legal_entity_registration_number (string): The registration number
            component of the legal entity. The length of this field is limited
            to 254 bytes. 254 bytes can hold 254 normal English characters.
            This value will be truncated if it is too long.
        legal_entity_registration_province (string): Optional province of the
            legal entity's address.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "legal_entity_registration_country":'legalEntityRegistrationCountry',
        "legal_entity_registration_number":'legalEntityRegistrationNumber',
        "legal_entity_registration_province":'legalEntityRegistrationProvince'
    }

    def __init__(self,
                 legal_entity_registration_country=None,
                 legal_entity_registration_number=None,
                 legal_entity_registration_province=None):
        """Constructor for the LegalEntityRegistration class"""

        # Initialize members of the class
        self.legal_entity_registration_country = legal_entity_registration_country
        self.legal_entity_registration_number = legal_entity_registration_number
        self.legal_entity_registration_province = legal_entity_registration_province


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        legal_entity_registration_country = dictionary.get('legalEntityRegistrationCountry')
        legal_entity_registration_number = dictionary.get('legalEntityRegistrationNumber')
        legal_entity_registration_province = dictionary.get('legalEntityRegistrationProvince')

        # Return an object of this model
        return cls(legal_entity_registration_country,
                   legal_entity_registration_number,
                   legal_entity_registration_province)





# -*- coding: utf-8 -*-


class AddDepositReferenceRequest(object):

    """Implementation of the 'AddDepositReferenceRequest' model.

    Deposit Reference.

    Attributes:
        deposit_reference (string): A Merchant User Deposit Reference.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "deposit_reference":'depositReference'
    }

    def __init__(self,
                 deposit_reference=None):
        """Constructor for the AddDepositReferenceRequest class"""

        # Initialize members of the class
        self.deposit_reference = deposit_reference


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        deposit_reference = dictionary.get('depositReference')

        # Return an object of this model
        return cls(deposit_reference)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.legal_entity_registration
import earthport-rest-api-client.models.address

class LegalEntityIdentity(object):

    """Implementation of the 'LegalEntityIdentity' model.

    The identity of a legal entity. The 'legalEntityName' is mandatory. You
    must supply one of 'legalEntityRegistration' or 'address'.

    Attributes:
        legal_entity_name (string): The name component of the legal entity.
            The length of this field is limited to 1024 bytes. 1024 bytes can
            hold 1024 normal English characters.
        legal_entity_registration (LegalEntityRegistration): This group
            consists of a legal entity registration number type and the
            country that the legal entity is registered in. Legal Entity
            Registration Number is mandatory Legal Entity Registration Country
            is mandatory Legal Entity Registration Province is optional.
        address (Address): Represents an address. Mandatory attributes are
            'addressLine1', 'city' and 'country'. All other attributes are
            optional.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "legal_entity_name":'legalEntityName',
        "legal_entity_registration":'legalEntityRegistration',
        "address":'address'
    }

    def __init__(self,
                 legal_entity_name=None,
                 legal_entity_registration=None,
                 address=None):
        """Constructor for the LegalEntityIdentity class"""

        # Initialize members of the class
        self.legal_entity_name = legal_entity_name
        self.legal_entity_registration = legal_entity_registration
        self.address = address


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        legal_entity_name = dictionary.get('legalEntityName')
        legal_entity_registration = earthport-rest-api-client.models.legal_entity_registration.LegalEntityRegistration.from_dictionary(dictionary.get('legalEntityRegistration')) if dictionary.get('legalEntityRegistration') else None
        address = earthport-rest-api-client.models.address.Address.from_dictionary(dictionary.get('address')) if dictionary.get('address') else None

        # Return an object of this model
        return cls(legal_entity_name,
                   legal_entity_registration,
                   address)





# -*- coding: utf-8 -*-

from .base_controller import BaseController
from ..api_helper import APIHelper
from ..configuration import Configuration
from ..http.auth.custom_header_auth import CustomHeaderAuth
from ..models.financial_transaction import FinancialTransaction
from ..models.cancel_transaction_response import CancelTransactionResponse
from ..models.search_transactions_response import SearchTransactionsResponse
from ..exceptions.api_exception import APIException

class TransactionsController(BaseController):

    """A Controller to access Endpoints in the earthport-rest-api-client API."""


    def get_transaction(self,
                        transaction_id,
                        id_type=None):
        """Does a GET request to /transactions/{transactionID}.

        Retrieves a Transaction.

        Args:
            transaction_id (string): A unique transaction ID. You can use
                earthport transaction id or merchant transaction reference.
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            FinancialTransaction: Response from the API. Transaction
                succesfully retrieved.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/transactions/{transactionID}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'transactionID': transaction_id
        })
        _query_parameters = {
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, FinancialTransaction.from_dictionary)

    def delete_cancel_transaction(self,
                                  transaction_id,
                                  id_type=None):
        """Does a DELETE request to /transactions/{transactionID}.

        Cancels a Transaction.

        Args:
            transaction_id (string): A unique transaction ID. You can use
                earthport transaction id or merchant transaction reference.
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            CancelTransactionResponse: Response from the API. Transaction
                succesfully Cancelled.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/transactions/{transactionID}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'transactionID': transaction_id
        })
        _query_parameters = {
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.delete(_query_url, headers=_headers)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, CancelTransactionResponse.from_dictionary)

    def search_transactions(self,
                            managed_merchant_name=None,
                            currency=None,
                            start_date_time=None,
                            end_date_time=None,
                            amount_from=None,
                            amount_to=None,
                            sort_order=None,
                            sort_fields=None,
                            merchant_transaction_id=None,
                            transaction_type=None,
                            transaction_status_code=None,
                            offset=None,
                            page_size=None):
        """Does a GET request to /transactions.

        Search Transactions.

        Args:
            managed_merchant_name (string, optional): Managed Merchant Name.
            currency (string, optional): currency.
            start_date_time (string, optional): Start Date Time.
            end_date_time (string, optional): End Date Time.
            amount_from (float, optional): Amount From.
            amount_to (float, optional): Amount To.
            sort_order (SortOrderEnum, optional): Sort Order.
            sort_fields (list of string, optional): Sort Fields.
            merchant_transaction_id (string, optional):
                merchantTransactionID.
            transaction_type (TransactionTypeEnum, optional): Transaction
                Type.
            transaction_status_code (int, optional): Transaction Status Code.
            offset (int, optional): This is used for pagination of resultsets.
                0-based starting offset of the page with respect to the entire
                resultset.
            page_size (int, optional): This is used for pagination of
                resultsets. Number of items per page to return. If empty the
                maximum allowable (25) number of records will be returned.

        Returns:
            SearchTransactionsResponse: Response from the API. Transaction
                succesfully retrieved.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/transactions'
        _query_parameters = {
            'managedMerchantName': managed_merchant_name,
            'currency': currency,
            'startDateTime': start_date_time,
            'endDateTime': end_date_time,
            'amountFrom': amount_from,
            'amountTo': amount_to,
            'sortOrder': sort_order,
            'sortFields': sort_fields,
            'merchantTransactionID': merchant_transaction_id,
            'transactionType': transaction_type,
            'transactionStatusCode': transaction_status_code,
            'offset': offset,
            'pageSize': page_size
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, SearchTransactionsResponse.from_dictionary)



# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.beneficiary_bank_account_fields_list

class BeneficiaryBankAccountGroup(object):

    """Implementation of the 'BeneficiaryBankAccountGroup' model.

    This type defines a bank account data group. Each group is normally
    represented as a row on the UI. 'groupLabel' is the UI test to display as
    a name for this row. 'mandatory' indicates whether values must be supplied
    in the fields of this group.

    Attributes:
        group_label (string): TODO: type description here.
        mandatory (string): TODO: type description here.
        beneficiary_bank_account_fields_list
            (BeneficiaryBankAccountFieldsList): This type defines a bank
            account field.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "group_label":'groupLabel',
        "mandatory":'mandatory',
        "beneficiary_bank_account_fields_list":'beneficiaryBankAccountFieldsList'
    }

    def __init__(self,
                 group_label=None,
                 mandatory=None,
                 beneficiary_bank_account_fields_list=None):
        """Constructor for the BeneficiaryBankAccountGroup class"""

        # Initialize members of the class
        self.group_label = group_label
        self.mandatory = mandatory
        self.beneficiary_bank_account_fields_list = beneficiary_bank_account_fields_list


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        group_label = dictionary.get('groupLabel')
        mandatory = dictionary.get('mandatory')
        beneficiary_bank_account_fields_list = earthport-rest-api-client.models.beneficiary_bank_account_fields_list.BeneficiaryBankAccountFieldsList.from_dictionary(dictionary.get('beneficiaryBankAccountFieldsList')) if dictionary.get('beneficiaryBankAccountFieldsList') else None

        # Return an object of this model
        return cls(group_label,
                   mandatory,
                   beneficiary_bank_account_fields_list)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.monetary_value
import earthport-rest-api-client.models.users_bank_id

class GetPayoutRequiredDataForBank(object):

    """Implementation of the 'getPayoutRequiredDataForBank' model.

    TODO: type model description here.

    Attributes:
        amount (MonetaryValue): Represents a monetary value containing a
            decimal amount value along with a currency code. The currency code
            is a three letter ISO 4217 code. E.g. GBP for British sterling
            pounds.
        payer (PayerTypeEnum): The Payer Type is optional. If no Payer Type is
            specified then the default value of authenticatedCaller will be
            used.
        service_level (ServiceLevelEnum): Supported service levels for a
            payout request (standard or express).
        users_bank_id (UsersBankID): This group consists of a collection of
            both the user ID group and beneficiary bank ID group. The 'userID'
            is a collection of user identifier types. The 'benBankID' is a
            collection of account identifier types. Both the 'userID' and
            'benBankID' fields are mandatory.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "users_bank_id":'usersBankID',
        "amount":'amount',
        "payer":'payer',
        "service_level":'serviceLevel'
    }

    def __init__(self,
                 users_bank_id=None,
                 amount=None,
                 payer=None,
                 service_level=None):
        """Constructor for the GetPayoutRequiredDataForBank class"""

        # Initialize members of the class
        self.amount = amount
        self.payer = payer
        self.service_level = service_level
        self.users_bank_id = users_bank_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        users_bank_id = earthport-rest-api-client.models.users_bank_id.UsersBankID.from_dictionary(dictionary.get('usersBankID')) if dictionary.get('usersBankID') else None
        amount = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('amount')) if dictionary.get('amount') else None
        payer = dictionary.get('payer')
        service_level = dictionary.get('serviceLevel')

        # Return an object of this model
        return cls(users_bank_id,
                   amount,
                   payer,
                   service_level)





# -*- coding: utf-8 -*-

class RequestedFXEnum(object):

    """Implementation of the 'RequestedFX' enum.

    Method of FX that is requested by the merchant and for which EPS2 will
    attempt to use in order to settle the payout request. FF (Fixed to Fixed)
    is where no FX will be performed as payout and beneficiary currencies are
    the same. FV (Fixed to Variable) uses the supplied payout request amount
    in order to determine the beneficiary amount. VF (Variable to Fixed) uses
    the supplied beneficiary amount in order to determine the payout amount.

    Attributes:
        FF: TODO: type description here.
        FV: TODO: type description here.
        VF: TODO: type description here.

    """

    FF = 'FF'

    FV = 'FV'

    VF = 'VF'




# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.statement_line_item
import earthport-rest-api-client.models.account_balance
import earthport-rest-api-client.models.pagination_result

class Statement(object):

    """Implementation of the 'Statement' model.

    TODO: type model description here.

    Attributes:
        statement_line_items (list of StatementLineItem): TODO: type
            description here.
        opening_balance (AccountBalance): This element represents the balance
            of a merchant account or a managed merchant account.
        closing_balance (AccountBalance): This element represents the balance
            of a merchant account or a managed merchant account.
        pagination_result (PaginationResult): This returns a paged set of
            results rather than the full result set.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "statement_line_items":'statementLineItems',
        "opening_balance":'openingBalance',
        "closing_balance":'closingBalance',
        "pagination_result":'paginationResult'
    }

    def __init__(self,
                 statement_line_items=None,
                 opening_balance=None,
                 closing_balance=None,
                 pagination_result=None):
        """Constructor for the Statement class"""

        # Initialize members of the class
        self.statement_line_items = statement_line_items
        self.opening_balance = opening_balance
        self.closing_balance = closing_balance
        self.pagination_result = pagination_result


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        statement_line_items = None
        if dictionary.get('statementLineItems') != None:
            statement_line_items = list()
            for structure in dictionary.get('statementLineItems'):
                statement_line_items.append(earthport-rest-api-client.models.statement_line_item.StatementLineItem.from_dictionary(structure))
        opening_balance = earthport-rest-api-client.models.account_balance.AccountBalance.from_dictionary(dictionary.get('openingBalance')) if dictionary.get('openingBalance') else None
        closing_balance = earthport-rest-api-client.models.account_balance.AccountBalance.from_dictionary(dictionary.get('closingBalance')) if dictionary.get('closingBalance') else None
        pagination_result = earthport-rest-api-client.models.pagination_result.PaginationResult.from_dictionary(dictionary.get('paginationResult')) if dictionary.get('paginationResult') else None

        # Return an object of this model
        return cls(statement_line_items,
                   opening_balance,
                   closing_balance,
                   pagination_result)





# -*- coding: utf-8 -*-


class BankAccountDetails(object):

    """Implementation of the 'BankAccountDetails' model.

    This group holds all possible account identifier types - listed below in
    alphabetical order. The data which should be supplied in this group
    differs depending on the bank account territory. Please refer to the
    integration guide for territory specific details of what should be
    supplied. The following set of parameter names are valid keys:-
    abaRoutingNumber, accountName, accountNumber, accountNumberPrefix,
    accountNumberSuffix, accountType, bankCode, bankName, branchCode, bic,
    holdingBranchName, iban, miscField1, miscField2, miscField3, sortCode,
    swiftBic.

    Attributes:
        key (string): Type which defines the allowable data which may be
            passed to the "key" element of the BankAccountDetails.
        value (string): Type which defines the allowable data which may be
            passed to the "value" element of the BankAccountDetails.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "key":'key',
        "value":'value'
    }

    def __init__(self,
                 key=None,
                 value=None):
        """Constructor for the BankAccountDetails class"""

        # Initialize members of the class
        self.key = key
        self.value = value


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        key = dictionary.get('key')
        value = dictionary.get('value')

        # Return an object of this model
        return cls(key,
                   value)





# -*- coding: utf-8 -*-


class SettlementCalendar(object):

    """Implementation of the 'SettlementCalendar' model.

    TODO: type model description here.

    Attributes:
        submit_by (string): TODO: type description here.
        for_value_on (string): Valid ISO 8601 date format YYYY-MM-DD.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "submit_by":'submitBy',
        "for_value_on":'forValueOn'
    }

    def __init__(self,
                 submit_by=None,
                 for_value_on=None):
        """Constructor for the SettlementCalendar class"""

        # Initialize members of the class
        self.submit_by = submit_by
        self.for_value_on = for_value_on


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        submit_by = dictionary.get('submitBy')
        for_value_on = dictionary.get('forValueOn')

        # Return an object of this model
        return cls(submit_by,
                   for_value_on)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.individual_name
import earthport-rest-api-client.models.address
import earthport-rest-api-client.models.birth_information
import earthport-rest-api-client.models.identification

class IndividualIdentity(object):

    """Implementation of the 'IndividualIdentity' model.

    The identity of an individual. The 'name' attribute is mandatory for an
    individual. You must supply at least identification entry or one birth
    information entry or one address entry.

    Attributes:
        name (IndividualName): The 'givenNames' attribute is mandatory. This
            is a space separated list of names (not including the family
            name).   You should supply names and not initials (wherever
            possible). See examples below.   The 'familyName' attribute is
            mandatory. This contains the single family name. See examples
            below.    *Example1 - a western citizen from a country which uses
            the common western naming convention(such as US, GB, FR, CA, DE
            etc...)*        Name = "John Michael Smith",        
            givenNames="John Michael" and familyName="Smith"   *Example2 - a
            citizen from a country which uses the eastern name order where the
            family name comes first, followed by their given names (such as
            Hungary, China, Japan, Korea, Singapore, Taiwan, Vietnam etc...)* 
            Name = "Máo Zédÿng",         giveNames="Zédÿng" and
            familyName="Máo"        Name = "Hidetoshi Nakata",        
            givenNames="Nakata" and familyName="Hidetoshi"       Name =
            "Ferenc Puskás",         giveNames="Puskás" and
            familyName="Ferenc"   *Example3 - middle east names*         Name=
            "Mohammed bin Rashid bin Saeed Al-Maktoum",        
            givenNames="Mohammed bin Rashid bin Saeed" and
            familName="Al-Maktoum"   *Example4 - single names, such as in
            Indonesia*         Name="Suharto",         givenNames="Suharto"
            and familyName="Suharto".
        address (Address): Represents an address. Mandatory attributes are
            'addressLine1', 'city' and 'country'. All other attributes are
            optional.
        birth_information (BirthInformation): The group consists of elements
            that define birth information for an individual.
        identification (list of Identification): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "address":'address',
        "birth_information":'birthInformation',
        "identification":'identification'
    }

    def __init__(self,
                 name=None,
                 address=None,
                 birth_information=None,
                 identification=None):
        """Constructor for the IndividualIdentity class"""

        # Initialize members of the class
        self.name = name
        self.address = address
        self.birth_information = birth_information
        self.identification = identification


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = earthport-rest-api-client.models.individual_name.IndividualName.from_dictionary(dictionary.get('name')) if dictionary.get('name') else None
        address = earthport-rest-api-client.models.address.Address.from_dictionary(dictionary.get('address')) if dictionary.get('address') else None
        birth_information = earthport-rest-api-client.models.birth_information.BirthInformation.from_dictionary(dictionary.get('birthInformation')) if dictionary.get('birthInformation') else None
        identification = None
        if dictionary.get('identification') != None:
            identification = list()
            for structure in dictionary.get('identification'):
                identification.append(earthport-rest-api-client.models.identification.Identification.from_dictionary(structure))

        # Return an object of this model
        return cls(name,
                   address,
                   birth_information,
                   identification)





# -*- coding: utf-8 -*-

from .base_controller import BaseController
from ..api_helper import APIHelper
from ..configuration import Configuration
from ..models.access_token_response import AccessTokenResponse
from ..exceptions.api_exception import APIException

class AuthenticationController(BaseController):

    """A Controller to access Endpoints in the earthport-rest-api-client API."""


    def create_get_access_token(self,
                                client_id,
                                client_secret,
                                grant_type='client_credentials'):
        """Does a POST request to /oauth/token.

        Verify client credentials and returns a bearer token

        Args:
            client_id (string): Client ID
            client_secret (string): Client Secret
            grant_type (GrantTypeEnum, optional): The grant type for OAuth2.0

        Returns:
            AccessTokenResponse: Response from the API. Access token
                generated.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri(Configuration.Server.AUTH)
        _query_builder += '/oauth/token'
        _query_parameters = {
            'grant_type': grant_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare form parameters
        _form_parameters = {
            'client_id': client_id,
            'client_secret': client_secret
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=_form_parameters)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, AccessTokenResponse.from_dictionary)



# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.beneficiary_identity_groups_list

class BeneficiaryIdentityFieldGroupChoice(object):

    """Implementation of the 'BeneficiaryIdentityFieldGroupChoice' model.

    This type defines that in common case at least one of the nested groups
    should be included into addBeneficiaryBankAccount request document. On UI
    it can be presented with drop-down list containing nested groups labels.
    'minElementNum' minimum this number of the nested groups should be
    specified (1 by default). 'maxElementNum' maximum this number of the
    nested groups can be specified (1 by default).

    Attributes:
        max_groups_list_num (int): TODO: type description here.
        min_groups_list_num (int): TODO: type description here.
        beneficiary_identity_field_groups_list (list of
            BeneficiaryIdentityGroupsList): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "max_groups_list_num":'maxGroupsListNum',
        "min_groups_list_num":'minGroupsListNum',
        "beneficiary_identity_field_groups_list":'beneficiaryIdentityFieldGroupsList'
    }

    def __init__(self,
                 max_groups_list_num=None,
                 min_groups_list_num=None,
                 beneficiary_identity_field_groups_list=None):
        """Constructor for the BeneficiaryIdentityFieldGroupChoice class"""

        # Initialize members of the class
        self.max_groups_list_num = max_groups_list_num
        self.min_groups_list_num = min_groups_list_num
        self.beneficiary_identity_field_groups_list = beneficiary_identity_field_groups_list


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        max_groups_list_num = dictionary.get('maxGroupsListNum')
        min_groups_list_num = dictionary.get('minGroupsListNum')
        beneficiary_identity_field_groups_list = None
        if dictionary.get('beneficiaryIdentityFieldGroupsList') != None:
            beneficiary_identity_field_groups_list = list()
            for structure in dictionary.get('beneficiaryIdentityFieldGroupsList'):
                beneficiary_identity_field_groups_list.append(earthport-rest-api-client.models.beneficiary_identity_groups_list.BeneficiaryIdentityGroupsList.from_dictionary(structure))

        # Return an object of this model
        return cls(max_groups_list_num,
                   min_groups_list_num,
                   beneficiary_identity_field_groups_list)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.user_id
import earthport-rest-api-client.models.ben_bank_id
import earthport-rest-api-client.models.transaction_id
import earthport-rest-api-client.models.monetary_value
import earthport-rest-api-client.models.fx_rate

class PayoutResponse(object):

    """Implementation of the 'PayoutResponse' model.

    Response object to the payout request APIs.

    Attributes:
        user_id (UserID): This group consists of all possible user identifier
            types. The 'epUserID' field is a unique identifier for a merchant
            and is the equivalent of a Virtual Account Number (VAN). The
            'merchantUserID' is a merchant specified identifier for an
            individual or company that an account was set up for. The
            'epUserID', 'merchantUserID' or both 'epUserID' and
            'merchantUserID' can be supplied. A mapping will be performed to
            retrieve the merchant user ID from the supplied EP user ID and
            vice versa. If both the 'epUserID' and 'merchantUserID' are
            supplied, a check will be performed to ensure that the two are
            mapped. If the two provided fields are not mapped, then a
            validation error code will be returned. At least one of the fields
            must be populated.
        ben_bank_id (BenBankID): This group consists of all possible
            beneficiary bank identifier types. The 'epBankID' field is a
            unique identifier for a beneficiary bank account. The
            'merchantBankID' is an optional merchant specified identifier for
            the beneficiary bank account. The 'epBankID', 'merchantBankID' or
            both 'epBankID' and 'merchantBankID' can be supplied. A mapping
            will be performed to retrieve the merchant bank ID from the
            supplied EP bank ID and vice versa. If both the 'epBankID' and
            'merchantBankID' are supplied, a check will be performed to ensure
            that the two are mapped. If the two provided fields are not
            mapped, then a validation error code will be returned. At least
            one of the fields must be populated.
        transaction_id (TransactionID): Transaction ID type which contains
            both the unique Earthport transaction ID and the merchant supplied
            transaction ID.
        correspondent_charges_expected (bool): A flag to indicate if
            correspondent charges are expected during the processing of the
            payout request.
        liquidity_value (MonetaryValue): Represents a monetary value
            containing a decimal amount value along with a currency code. The
            currency code is a three letter ISO 4217 code. E.g. GBP for
            British sterling pounds.
        settlement_value (MonetaryValue): Represents a monetary value
            containing a decimal amount value along with a currency code. The
            currency code is a three letter ISO 4217 code. E.g. GBP for
            British sterling pounds.
        fee_value (MonetaryValue): Represents a monetary value containing a
            decimal amount value along with a currency code. The currency code
            is a three letter ISO 4217 code. E.g. GBP for British sterling
            pounds.
        fx_method_expected (FXMethodEnum): Method of FX that will be used to
            settle the payout request.
        fx_rate (FXRate): Represents an FX rate between two currencies, the
            rate is restricted to 6 decimal places. The currency code is a
            three letter ISO 4217 code. E.g. GBP for British sterling pounds.
        accepted_date (string): TODO: type description here.
        expected_settlement_date (string): Valid ISO 8601 date format
            YYYY-MM-DD.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "transaction_id":'transactionID',
        "liquidity_value":'liquidityValue',
        "settlement_value":'settlementValue',
        "user_id":'userID',
        "ben_bank_id":'benBankID',
        "correspondent_charges_expected":'correspondentChargesExpected',
        "fee_value":'feeValue',
        "fx_method_expected":'fxMethodExpected',
        "fx_rate":'fxRate',
        "accepted_date":'acceptedDate',
        "expected_settlement_date":'expectedSettlementDate'
    }

    def __init__(self,
                 transaction_id=None,
                 liquidity_value=None,
                 settlement_value=None,
                 user_id=None,
                 ben_bank_id=None,
                 correspondent_charges_expected=None,
                 fee_value=None,
                 fx_method_expected=None,
                 fx_rate=None,
                 accepted_date=None,
                 expected_settlement_date=None):
        """Constructor for the PayoutResponse class"""

        # Initialize members of the class
        self.user_id = user_id
        self.ben_bank_id = ben_bank_id
        self.transaction_id = transaction_id
        self.correspondent_charges_expected = correspondent_charges_expected
        self.liquidity_value = liquidity_value
        self.settlement_value = settlement_value
        self.fee_value = fee_value
        self.fx_method_expected = fx_method_expected
        self.fx_rate = fx_rate
        self.accepted_date = accepted_date
        self.expected_settlement_date = expected_settlement_date


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        transaction_id = earthport-rest-api-client.models.transaction_id.TransactionID.from_dictionary(dictionary.get('transactionID')) if dictionary.get('transactionID') else None
        liquidity_value = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('liquidityValue')) if dictionary.get('liquidityValue') else None
        settlement_value = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('settlementValue')) if dictionary.get('settlementValue') else None
        user_id = earthport-rest-api-client.models.user_id.UserID.from_dictionary(dictionary.get('userID')) if dictionary.get('userID') else None
        ben_bank_id = earthport-rest-api-client.models.ben_bank_id.BenBankID.from_dictionary(dictionary.get('benBankID')) if dictionary.get('benBankID') else None
        correspondent_charges_expected = dictionary.get('correspondentChargesExpected')
        fee_value = earthport-rest-api-client.models.monetary_value.MonetaryValue.from_dictionary(dictionary.get('feeValue')) if dictionary.get('feeValue') else None
        fx_method_expected = dictionary.get('fxMethodExpected')
        fx_rate = earthport-rest-api-client.models.fx_rate.FXRate.from_dictionary(dictionary.get('fxRate')) if dictionary.get('fxRate') else None
        accepted_date = dictionary.get('acceptedDate')
        expected_settlement_date = dictionary.get('expectedSettlementDate')

        # Return an object of this model
        return cls(transaction_id,
                   liquidity_value,
                   settlement_value,
                   user_id,
                   ben_bank_id,
                   correspondent_charges_expected,
                   fee_value,
                   fx_method_expected,
                   fx_rate,
                   accepted_date,
                   expected_settlement_date)





# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.beneficiary_bank_account_list_items

class BeneficiaryBankAccountField(object):

    """Implementation of the 'BeneficiaryBankAccountField' model.

    Each beneficiaryBankAccountField would normally be displayed in the UI
    from left to right based on the tabOrder attribute. The
    beneficiaryBankAccountField element contains the following attributes:-
    tabOrder - indicates the ordering of this field in the UIparameterName -
    the name of the corresponding Earthport parameter to use when calling
    addBeneficiaryBankAcountdisplaySize - a suggested field size to
    displaymaxSize - suggested client side syntactic validation
    ruledescription - suggested roll-over or help text description to assist
    usersseparator - the separator to display following (to the right hand
    side) this field, usually '-' or '/' input - whether this field should be
    represented as a text field or a list of optionssubTitle- if present
    contains a sub-label to be displayed with the fieldlocale - the
    localisation setting of this particular recordvalue - the current value of
    this field, populated by the getBeneficiaryBankAccount service.

    Attributes:
        description (string): TODO: type description here.
        display_size (int): TODO: type description here.
        input (BeneficiaryBankAccountFieldInputEnum): Supported input types
            for a bank registration UI.
        locale (string): TODO: type description here.
        max_size (int): TODO: type description here.
        parameter_name (string): TODO: type description here.
        separator (string): TODO: type description here.
        sub_title (string): TODO: type description here.
        tab_order (int): TODO: type description here.
        value (string): TODO: type description here.
        list_items (BeneficiaryBankAccountListItems): The
            beneficiaryBankAccountField contains optional listItem
            sub-elements. The listItem sub-elements would normally be present
            where the inputType attribute is 'list'.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "description":'description',
        "display_size":'displaySize',
        "input":'input',
        "locale":'locale',
        "max_size":'maxSize',
        "parameter_name":'parameterName',
        "separator":'separator',
        "sub_title":'subTitle',
        "tab_order":'tabOrder',
        "value":'value',
        "list_items":'listItems'
    }

    def __init__(self,
                 description=None,
                 display_size=None,
                 input=None,
                 locale=None,
                 max_size=None,
                 parameter_name=None,
                 separator=None,
                 sub_title=None,
                 tab_order=None,
                 value=None,
                 list_items=None):
        """Constructor for the BeneficiaryBankAccountField class"""

        # Initialize members of the class
        self.description = description
        self.display_size = display_size
        self.input = input
        self.locale = locale
        self.max_size = max_size
        self.parameter_name = parameter_name
        self.separator = separator
        self.sub_title = sub_title
        self.tab_order = tab_order
        self.value = value
        self.list_items = list_items


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        description = dictionary.get('description')
        display_size = dictionary.get('displaySize')
        input = dictionary.get('input')
        locale = dictionary.get('locale')
        max_size = dictionary.get('maxSize')
        parameter_name = dictionary.get('parameterName')
        separator = dictionary.get('separator')
        sub_title = dictionary.get('subTitle')
        tab_order = dictionary.get('tabOrder')
        value = dictionary.get('value')
        list_items = earthport-rest-api-client.models.beneficiary_bank_account_list_items.BeneficiaryBankAccountListItems.from_dictionary(dictionary.get('listItems')) if dictionary.get('listItems') else None

        # Return an object of this model
        return cls(description,
                   display_size,
                   input,
                   locale,
                   max_size,
                   parameter_name,
                   separator,
                   sub_title,
                   tab_order,
                   value,
                   list_items)





# -*- coding: utf-8 -*-


class BulkFXDetail(object):

    """Implementation of the 'BulkFXDetail' model.

    TODO: type model description here.

    Attributes:
        sell_currency (string): Valid supported ISO 4217 3-character currency
            code.
        buy_currency (string): Valid supported ISO 4217 3-character currency
            code.
        buy_country (string): Valid supported ISO 3166 2-character country
            code.
        service_level (ServiceLevelEnum): Supported service levels for a
            payout request (standard or express).
        buy_fx_rate (float): TODO: type description here.
        sell_fx_rate (float): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "sell_currency":'sellCurrency',
        "buy_currency":'buyCurrency',
        "buy_country":'buyCountry',
        "service_level":'serviceLevel',
        "buy_fx_rate":'buyFxRate',
        "sell_fx_rate":'sellFxRate'
    }

    def __init__(self,
                 sell_currency=None,
                 buy_currency=None,
                 buy_country=None,
                 service_level=None,
                 buy_fx_rate=None,
                 sell_fx_rate=None):
        """Constructor for the BulkFXDetail class"""

        # Initialize members of the class
        self.sell_currency = sell_currency
        self.buy_currency = buy_currency
        self.buy_country = buy_country
        self.service_level = service_level
        self.buy_fx_rate = buy_fx_rate
        self.sell_fx_rate = sell_fx_rate


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        sell_currency = dictionary.get('sellCurrency')
        buy_currency = dictionary.get('buyCurrency')
        buy_country = dictionary.get('buyCountry')
        service_level = dictionary.get('serviceLevel')
        buy_fx_rate = dictionary.get('buyFxRate')
        sell_fx_rate = dictionary.get('sellFxRate')

        # Return an object of this model
        return cls(sell_currency,
                   buy_currency,
                   buy_country,
                   service_level,
                   buy_fx_rate,
                   sell_fx_rate)





# -*- coding: utf-8 -*-

from .base_controller import BaseController
from ..api_helper import APIHelper
from ..configuration import Configuration
from ..http.auth.custom_header_auth import CustomHeaderAuth
from ..models.payout_response import PayoutResponse
from ..models.get_payout_required_data_response import GetPayoutRequiredDataResponse
from ..exceptions.api_exception import APIException

class PaymentsController(BaseController):

    """A Controller to access Endpoints in the earthport-rest-api-client API."""


    def create_payment(self,
                       create_payment_request=None):
        """Does a POST request to /payments.

        Creates a User (or updates an existing User), adds a Beneficiary Bank
        Account to this user and creates a new payment.

        Args:
            create_payment_request (CreatePaymentRequest, optional): The
                payment request

        Returns:
            PayoutResponse: Response from the API. Payment succesfully
                created.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/payments'
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_payment_request))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, PayoutResponse.from_dictionary)

    def create_payment_registered_beneficiary(self,
                                              user_id,
                                              bank_id,
                                              payment_registered_beneficiary_request=None,
                                              id_type=None):
        """Does a POST request to /users/{userID}/bank-accounts/{bankID}/payments.

        Creates a new payment for a previously registered beneficiary bank
        account (and user).

        Args:
            user_id (string): The payer's unique id. It can be either VAN or
                merchant id.
            bank_id (string): Unique ID for the beneficiary bank account. It
                can be either earthport id or merchant id.
            payment_registered_beneficiary_request
                (PaymentRegisteredBeneficiaryRequest, optional):
                CreatePaymentRegisteredBeneficiaryRequest
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            PayoutResponse: Response from the API. Payment succesfully
                created.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/users/{userID}/bank-accounts/{bankID}/payments'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'userID': user_id,
            'bankID': bank_id
        })
        _query_parameters = {
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(payment_registered_beneficiary_request))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, PayoutResponse.from_dictionary)

    def get_purpose_of_payment_metadata(self,
                                        user_id,
                                        bank_id,
                                        amount=None,
                                        currency=None,
                                        payer_type=None,
                                        service_level=None,
                                        id_type=None):
        """Does a GET request to /users/{userID}/bank-accounts/{bankID}/payments/meta.

        Returns Purpose of Payment metadata for a payment to a beneficiary
        bank account which has previously been registered.

        Args:
            user_id (string): The payer's unique id. It can be either VAN or
                merchant id.
            bank_id (string): Unique ID for the beneficiary bank account. It
                can be either earthport id or merchant id.
            amount (int, optional): Amount
            currency (string, optional): currency
            payer_type (string, optional): The type of Payer. Allowed values
                are authenticatedCaller, managedMerchant and user.
            service_level (string, optional): Service Level. Allowed values
                are standard and express.
            id_type (IdTypeEnum, optional): idType for the path parameters.
                This allows you to specify either your own UIDs or Earthport
                generated UIDs. The Earthport generated UIDs will be used by
                default.

        Returns:
            GetPayoutRequiredDataResponse: Response from the API. Payment
                metadata succesfully returned.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/users/{userID}/bank-accounts/{bankID}/payments/meta'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'userID': user_id,
            'bankID': bank_id
        })
        _query_parameters = {
            'amount': amount,
            'currency': currency,
            'payerType': payer_type,
            'serviceLevel': service_level,
            'idType': id_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetPayoutRequiredDataResponse.from_dictionary)

    def get_metadata_for_payment_request(self,
                                         country_code,
                                         currency_code,
                                         beneficiary_identity_entity_type=None,
                                         locale=None,
                                         service_level=None):
        """Does a GET request to /payments/meta.

        Returns required field for creating the payment request.

        Args:
            country_code (string): Valid supported ISO 3166 2-character
                country code.
            currency_code (string): Valid supported ISO 4217 3-character
                currency code.
            beneficiary_identity_entity_type
                (BeneficiaryIdentityEntityTypeEnum, optional): Type of
                beneficiary identity
            locale (string, optional): Localization String e.g. en_GB, en_US
            service_level (string, optional): Service Level. Allowed values
                are standard and express.

        Returns:
            GetPayoutRequiredDataResponse: Response from the API. Payment
                metadata succesfully returned.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.get_base_uri()
        _query_builder += '/payments/meta'
        _query_parameters = {
            'countryCode': country_code,
            'currencyCode': currency_code,
            'beneficiaryIdentityEntityType': beneficiary_identity_entity_type,
            'locale': locale,
            'serviceLevel': service_level
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 400:
            raise APIException('The requested operation could not be performed. Input Request is invalid or incorrect.', _context)
        elif _context.response.status_code == 401:
            raise APIException('Unauthorized - Invalid API Key and Token.', _context)
        elif _context.response.status_code == 500:
            raise APIException('An internal error has occurred in the Earthport payment platform.', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetPayoutRequiredDataResponse.from_dictionary)



# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.payer_additional_data

class PayerAdditionalDataList(object):

    """Implementation of the 'PayerAdditionalDataList' model.

    Represents a list of Additional Data for Beneficiary Identity.

    Attributes:
        additional_data (list of PayerAdditionalData): TODO: type description
            here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "additional_data":'additionalData'
    }

    def __init__(self,
                 additional_data=None):
        """Constructor for the PayerAdditionalDataList class"""

        # Initialize members of the class
        self.additional_data = additional_data


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        additional_data = None
        if dictionary.get('additionalData') != None:
            additional_data = list()
            for structure in dictionary.get('additionalData'):
                additional_data.append(earthport-rest-api-client.models.payer_additional_data.PayerAdditionalData.from_dictionary(structure))

        # Return an object of this model
        return cls(additional_data)





# -*- coding: utf-8 -*-


class FXRate(object):

    """Implementation of the 'FXRate' model.

    Represents an FX rate between two currencies, the rate is restricted to 6
    decimal places. The currency code is a three letter ISO 4217 code. E.g.
    GBP for British sterling pounds.

    Attributes:
        buy_currency (string): Valid supported ISO 4217 3-character currency
            code.
        rate (float): TODO: type description here.
        sell_currency (string): Valid supported ISO 4217 3-character currency
            code.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "buy_currency":'buyCurrency',
        "rate":'rate',
        "sell_currency":'sellCurrency'
    }

    def __init__(self,
                 buy_currency=None,
                 rate=None,
                 sell_currency=None):
        """Constructor for the FXRate class"""

        # Initialize members of the class
        self.buy_currency = buy_currency
        self.rate = rate
        self.sell_currency = sell_currency


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        buy_currency = dictionary.get('buyCurrency')
        rate = dictionary.get('rate')
        sell_currency = dictionary.get('sellCurrency')

        # Return an object of this model
        return cls(buy_currency,
                   rate,
                   sell_currency)





# -*- coding: utf-8 -*-

class FXMethodEnum(object):

    """Implementation of the 'FXMethod' enum.

    Method of FX that will be used to settle the payout request.

    Attributes:
        ENUM_NO FX: TODO: type description here.
        ENUM_FORWARD FX: TODO: type description here.
        ENUM_FX ON RECEIPT: TODO: type description here.

    """

    ENUM_NO_FX = 'no fx'

    ENUM_FORWARD_FX = 'forward fx'

    ENUM_FX_ON_RECEIPT = 'fx on receipt'




# -*- coding: utf-8 -*-

import earthport-rest-api-client.models.ben_bank_id_merchant
import earthport-rest-api-client.models.identity
import earthport-rest-api-client.models.bank_account_details

class BankAccount(object):

    """Implementation of the 'BankAccount' model.

    The beneficiary bank account Object.

    Attributes:
        ben_bank_id (BenBankIDMerchant): This group consists of merchant
            beneficiary bank identifier only.
        beneficiary_identity (Identity): Represents the identity of an
            individual or legal entity. You must specify one of either an
            individual identity or legal entity identity or unstructured
            identity.
        description (string): Type which defines a beneficiary bank account
            description. Each bank account must be given a description
            therefore this is a mandatory component of the
            BeneficiaryBankAccount complex type.
        country_code (string): Valid supported ISO 3166 2-character country
            code.
        currency_code (string): Valid supported ISO 4217 3-character currency
            code.
        bank_account_details (list of BankAccountDetails): TODO: type
            description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "beneficiary_identity":'beneficiaryIdentity',
        "ben_bank_id":'benBankID',
        "description":'description',
        "country_code":'countryCode',
        "currency_code":'currencyCode',
        "bank_account_details":'bankAccountDetails'
    }

    def __init__(self,
                 beneficiary_identity=None,
                 ben_bank_id=None,
                 description=None,
                 country_code=None,
                 currency_code=None,
                 bank_account_details=None):
        """Constructor for the BankAccount class"""

        # Initialize members of the class
        self.ben_bank_id = ben_bank_id
        self.beneficiary_identity = beneficiary_identity
        self.description = description
        self.country_code = country_code
        self.currency_code = currency_code
        self.bank_account_details = bank_account_details


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        beneficiary_identity = earthport-rest-api-client.models.identity.Identity.from_dictionary(dictionary.get('beneficiaryIdentity')) if dictionary.get('beneficiaryIdentity') else None
        ben_bank_id = earthport-rest-api-client.models.ben_bank_id_merchant.BenBankIDMerchant.from_dictionary(dictionary.get('benBankID')) if dictionary.get('benBankID') else None
        description = dictionary.get('description')
        country_code = dictionary.get('countryCode')
        currency_code = dictionary.get('currencyCode')
        bank_account_details = None
        if dictionary.get('bankAccountDetails') != None:
            bank_account_details = list()
            for structure in dictionary.get('bankAccountDetails'):
                bank_account_details.append(earthport-rest-api-client.models.bank_account_details.BankAccountDetails.from_dictionary(structure))

        # Return an object of this model
        return cls(beneficiary_identity,
                   ben_bank_id,
                   description,
                   country_code,
                   currency_code,
                   bank_account_details)





# -*- coding: utf-8 -*-

class IdTypeEnum(object):

    """Implementation of the 'idType' enum.

    TODO: type enum description here.

    Attributes:
        MERCHANT: TODO: type description here.
        EARTHPORT: TODO: type description here.

    """

    MERCHANT = 'merchant'

    EARTHPORT = 'earthport'

